@@ -2,7 +2,7 @@
  *
  * $Id: classdef.cpp,v 1.54 2001/03/19 19:27:39 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -47,6 +47,7 @@ ClassDef::ClassDef(
  : Definition(defFileName,defLine,removeRedundantWhiteSpace(nm),0,0,isSymbol) 
 {
   m_compType=ct;
+  m_isObjC = FALSE;
   QCString compoundName=compoundTypeString();
   if (fName)
   {
@@ -92,7 +93,7 @@ ClassDef::ClassDef(
   m_artificial = FALSE;
   m_isAbstract = FALSE;
   m_isStatic = FALSE;
-  m_isObjC = FALSE;
+  m_isTemplArg = FALSE;
   m_membersMerged = FALSE;
   m_categoryOf = 0;
   QCString ns;
@@ -224,13 +225,14 @@ void ClassDef::internalInsertMember(MemberDef *md,
   //printf("adding %s::%s\n",name().data(),md->name().data());
   if (!isReference())
   {
+    static bool sortBriefDocs = Config_getBool("SORT_BRIEF_DOCS");
     /********************************************/
     /* insert member in the declaration section */
     /********************************************/
     if (md->isRelated() && 
         (Config_getBool("EXTRACT_PRIVATE") || prot!=Private))
     {
-      if (Config_getBool("SORT_BRIEF_DOCS"))
+      if (sortBriefDocs)
         related.inSort(md);
       else
         related.append(md);
@@ -238,7 +240,7 @@ void ClassDef::internalInsertMember(MemberDef *md,
     }
     else if (md->isFriend())
     {
-      if (Config_getBool("SORT_BRIEF_DOCS"))
+      if (sortBriefDocs)
         friends.inSort(md);
       else
         friends.append(md);
@@ -249,28 +251,28 @@ void ClassDef::internalInsertMember(MemberDef *md,
       switch (md->memberType())
       {
         case MemberDef::Signal: // Qt specific
-          if (Config_getBool("SORT_BRIEF_DOCS"))
+          if (sortBriefDocs)
             signals.inSort(md);
           else
             signals.append(md);
           md->setSectionList(this,&signals);
           break;
         case MemberDef::DCOP:   // KDE2 specific
-          if (Config_getBool("SORT_BRIEF_DOCS"))
+          if (sortBriefDocs)
             dcopMethods.inSort(md);
           else
             dcopMethods.append(md);
           md->setSectionList(this,&dcopMethods);
           break;
         case MemberDef::Property:
-          if (Config_getBool("SORT_BRIEF_DOCS"))
+          if (sortBriefDocs)
             properties.inSort(md);
           else
             properties.append(md);
           md->setSectionList(this,&properties);
           break;
         case MemberDef::Event:
-          if (Config_getBool("SORT_BRIEF_DOCS"))
+          if (sortBriefDocs)
             events.inSort(md);
           else
             events.append(md);
@@ -281,7 +283,7 @@ void ClassDef::internalInsertMember(MemberDef *md,
           {
             case Protected: 
             case Package: // slots in packages are not possible!
-              if (Config_getBool("SORT_BRIEF_DOCS"))
+              if (sortBriefDocs)
                 proSlots.inSort(md);
               else
                 proSlots.append(md); 
@@ -289,14 +291,14 @@ void ClassDef::internalInsertMember(MemberDef *md,
               break;
               break;
             case Public:    
-              if (Config_getBool("SORT_BRIEF_DOCS"))
+              if (sortBriefDocs)
                 pubSlots.inSort(md);
               else
                 pubSlots.append(md); 
               md->setSectionList(this,&pubSlots);
               break;
             case Private:   
-              if (Config_getBool("SORT_BRIEF_DOCS"))
+              if (sortBriefDocs)
                 priSlots.inSort(md);
               else
                 priSlots.append(md);
@@ -312,28 +314,28 @@ void ClassDef::internalInsertMember(MemberDef *md,
               switch (prot)
               {
                 case Protected: 
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     proStaticAttribs.inSort(md);
                   else
                     proStaticAttribs.append(md); 
                   md->setSectionList(this,&proStaticAttribs);
                   break;
                 case Package: 
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     pacStaticAttribs.inSort(md);
                   else
                     pacStaticAttribs.append(md); 
                   md->setSectionList(this,&pacStaticAttribs);
                   break;
                 case Public:    
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     pubStaticAttribs.inSort(md);
                   else
                     pubStaticAttribs.append(md); 
                   md->setSectionList(this,&pubStaticAttribs);
                   break;
                 case Private:   
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     priStaticAttribs.inSort(md);
                   else
                     priStaticAttribs.append(md); 
@@ -346,28 +348,28 @@ void ClassDef::internalInsertMember(MemberDef *md,
               switch (prot)
               {
                 case Protected: 
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     proStaticMethods.inSort(md);
                   else
                     proStaticMethods.append(md); 
                   md->setSectionList(this,&proStaticMethods);
                   break;
                 case Package: 
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     pacStaticMethods.inSort(md);
                   else
                     pacStaticMethods.append(md); 
                   md->setSectionList(this,&pacStaticMethods);
                   break;
                 case Public:    
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     pubStaticMethods.inSort(md);
                   else
                     pubStaticMethods.append(md); 
                   md->setSectionList(this,&pubStaticMethods);
                   break;
                 case Private:   
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     priStaticMethods.inSort(md);
                   else
                     priStaticMethods.append(md); 
@@ -383,28 +385,28 @@ void ClassDef::internalInsertMember(MemberDef *md,
               switch (prot)
               {
                 case Protected: 
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     proAttribs.inSort(md);
                   else
                     proAttribs.append(md); 
                   md->setSectionList(this,&proAttribs);
                   break;
                 case Package:
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     pacAttribs.inSort(md);
                   else
                     pacAttribs.append(md);
                   md->setSectionList(this,&pacAttribs);
                   break;
                 case Public:    
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     pubAttribs.inSort(md);
                   else
                     pubAttribs.append(md); 
                   md->setSectionList(this,&pubAttribs);
                   break;
                 case Private:   
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     priAttribs.inSort(md);
                   else
                     priAttribs.append(md); 
@@ -417,28 +419,28 @@ void ClassDef::internalInsertMember(MemberDef *md,
               switch (prot)
               {
                 case Protected: 
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     proTypes.inSort(md);
                   else
                     proTypes.append(md); 
                   md->setSectionList(this,&proTypes); 
                   break;
                 case Package: 
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     pacTypes.inSort(md);
                   else
                     pacTypes.append(md); 
                   md->setSectionList(this,&pacTypes); 
                   break;
                 case Public:    
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     pubTypes.inSort(md);
                   else
                     pubTypes.append(md); 
                   md->setSectionList(this,&pubTypes); 
                   break;
                 case Private:   
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     priTypes.inSort(md);
                   else
                     priTypes.append(md); 
@@ -451,28 +453,28 @@ void ClassDef::internalInsertMember(MemberDef *md,
               switch (prot)
               {
                 case Protected: 
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     proMethods.inSort(md);
                   else
                     proMethods.append(md); 
                   md->setSectionList(this,&proMethods); 
                   break;
                 case Package: 
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     pacMethods.inSort(md);
                   else
                     pacMethods.append(md); 
                   md->setSectionList(this,&pacMethods); 
                   break;
                 case Public:    
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     pubMethods.inSort(md);
                   else
                     pubMethods.append(md); 
                   md->setSectionList(this,&pubMethods); 
                   break;
                 case Private:   
-                  if (Config_getBool("SORT_BRIEF_DOCS"))
+                  if (sortBriefDocs)
                     priMethods.inSort(md);
                   else
                     priMethods.append(md); 
@@ -1024,7 +1026,7 @@ void ClassDef::writeDocumentation(OutputList &ol)
               m_compType == Interface && m_isObjC ? Class : m_compType,
               m_tempArgs != 0);
   
-  startFile(ol,getOutputFileBase(),name(),pageTitle);  
+  startFile(ol,getOutputFileBase(),name(),pageTitle,HLI_ClassVisible);  
   if (getOuterScope()!=Doxygen::globalScope)
   {
     writeNavigationPath(ol);
@@ -1512,6 +1514,7 @@ void ClassDef::writeMemberDocumentation(OutputList &ol)
   if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
     ol.disable(OutputGenerator::Html);
+    Doxygen::suppressDocWarnings = TRUE;
   }
   
   typedefMembers.writeDocumentation(ol,name(),this,
@@ -1541,6 +1544,7 @@ void ClassDef::writeMemberDocumentation(OutputList &ol)
   if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
     ol.enable(OutputGenerator::Html);
+    Doxygen::suppressDocWarnings = FALSE;
   }
 }
 
@@ -1645,7 +1649,7 @@ void ClassDef::writeMemberList(OutputList &ol)
   ol.disableAllBut(OutputGenerator::Html);
 
   startFile(ol,m_memListFileName,m_memListFileName,
-            theTranslator->trMemberList());
+            theTranslator->trMemberList(),HLI_ClassVisible);
   startTitle(ol,0);
   ol.parseText(displayName()+" "+theTranslator->trMemberList());
   endTitle(ol,0,0);
@@ -1883,7 +1887,7 @@ void ClassDef::setTemplateArguments(ArgumentList *al)
  */
 bool ClassDef::hasNonReferenceSuperClass()
 {
-  bool found=!isReference() && isLinkableInProject(); 
+  bool found=!isReference() && isLinkableInProject() && !isHidden(); 
   if (found) 
   {
     return TRUE; // we're done if this class is not a reference
@@ -2025,7 +2029,7 @@ bool ClassDef::isLinkableInProject() const
   else
   {
     return !name().isEmpty() &&    /* no name */
-      !m_artificial &&
+      !m_artificial && !isHidden() &&
       name().find('@')==-1 && /* anonymous compound */
       (m_prot!=Private || Config_getBool("EXTRACT_PRIVATE")) && /* private */
       (!m_isLocal || Config_getBool("EXTRACT_LOCAL_CLASSES")) && /* local */
@@ -2051,22 +2055,27 @@ bool ClassDef::isLinkable() const
 /*! the class is visible in a class diagram, or class hierarchy */
 bool ClassDef::isVisibleInHierarchy() 
 { 
-    return // show all classes or a subclass is visible
-      (Config_getBool("ALLEXTERNALS") || hasNonReferenceSuperClass()) &&
+  static bool allExternals     = Config_getBool("ALLEXTERNALS");
+  static bool extractPrivate   = Config_getBool("EXTRACT_PRIVATE");
+  static bool hideUndocClasses = Config_getBool("HIDE_UNDOC_CLASSES");
+  static bool extractStatic    = Config_getBool("EXTRACT_STATIC");
+
+  return // show all classes or a subclass is visible
+      (allExternals || hasNonReferenceSuperClass()) &&
       // and not an annonymous compound
       name().find('@')==-1 &&
       // not an artifically introduced class
       !m_artificial &&
       // and not privately inherited
-      (m_prot!=Private || Config_getBool("EXTRACT_PRIVATE")) &&
+      (m_prot!=Private || extractPrivate) &&
       // documented or shown anyway or documentation is external 
       (hasDocumentation() || 
-       !Config_getBool("HIDE_UNDOC_CLASSES") || 
+       !hideUndocClasses || 
        (m_templateMaster && m_templateMaster->hasDocumentation()) || 
        isReference()
       ) &&
       // is not part of an unnamed namespace or shown anyway
-      (!m_isStatic || Config_getBool("EXTRACT_STATIC"));
+      (!m_isStatic || extractStatic);
 }
 
 bool ClassDef::hasDocumentation() const
@@ -2713,7 +2722,11 @@ void ClassDef::setGroupDefForAllMembers(GroupDef *gd,Grouping::GroupPri_t pri,co
 
 void ClassDef::addInnerCompound(Definition *d)
 {
-  m_innerClasses->inSort(d->localName(),(ClassDef *)d);
+  if (d->definitionType()==Definition::TypeClass) // only classes can be
+                                                  // nested in classes.
+  {
+    m_innerClasses->inSort(d->localName(),(ClassDef *)d);
+  }
 }
 
 Definition *ClassDef::findInnerCompound(const char *name)
@@ -2778,6 +2791,7 @@ ClassDef *ClassDef::insertTemplateInstance(const QCString &fileName,
         fileName,startLine,name()+templSpec,ClassDef::Class);
     templateClass->setTemplateMaster(this);
     templateClass->setOuterScope(getOuterScope());
+    templateClass->setHidden(isHidden());
     m_templateInstances->insert(templSpec,templateClass);
     freshInstance=TRUE;
   }
