@@ -2,7 +2,7 @@
  *
  * $Id: classdef.h,v 1.39 2001/03/19 19:27:39 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -183,6 +183,17 @@ class ClassDef : public Definition
       return m_usesIntfClassDict;
     }
 
+    /** Marks this class as a template argument of some another class */
+    void makeTemplateArgument(bool b=TRUE)
+    {
+      m_isTemplArg = b;
+    }
+
+    bool isTemplateArgument() const
+    {
+      return m_isTemplArg;
+    }
+
     /*! Returns the definition of a nested compound if
      *  available, or 0 otherwise.
      *  @param name The name of the nested compound
@@ -465,6 +476,8 @@ class ClassDef : public Definition
      *  class which is extended.
      */
     ClassDef *m_categoryOf;
+
+    bool m_isTemplArg;
 };
 
 /*! \brief Class that contains information about a usage relation. 
