@@ -90,6 +90,7 @@
 "    <xsd:simpleContent>\n"
 "      <xsd:extension base=\"xsd:string\">\n"
 "        <xsd:attribute name=\"refid\" type=\"xsd:string\" />\n"
+"        <xsd:attribute name=\"prot\" type=\"DoxProtectionKind\" use=\"optional\"/>\n"
 "      </xsd:extension>\n"
 "    </xsd:simpleContent>\n"
 "  </xsd:complexType>\n"
@@ -122,6 +123,7 @@
 "      <xsd:element name=\"name\" />\n"
 "      <xsd:element name=\"read\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"write\" minOccurs=\"0\" />\n"
+"      <xsd:element name=\"bitfield\" minOccurs=\"0\" />\n"
 "      <xsd:element name=\"reimplements\" type=\"reimplementType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"reimplementedby\" type=\"reimplementType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"param\" type=\"paramType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
@@ -151,6 +153,7 @@
 "\n"
 "  <xsd:complexType name=\"descriptionType\" mixed=\"true\">\n"
 "    <xsd:sequence>\n"
+"      <xsd:element name=\"title\" type=\"xsd:string\" minOccurs=\"0\"/>	    \n"
 "      <xsd:element name=\"para\" type=\"docParaType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"sect1\" type=\"docSect1Type\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
 "      <xsd:element name=\"internal\" type=\"docInternalType\" minOccurs=\"0\" />\n"
@@ -350,6 +353,12 @@
 "      <xsd:element name=\"copy\" type=\"docEmptyType\" />\n"
 "      <xsd:element name=\"trademark\" type=\"docEmptyType\" />\n"
 "      <xsd:element name=\"registered\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"lsquo\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"rsquo\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"ldquo\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"rdquo\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"ndash\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"mdash\" type=\"docEmptyType\" />\n"
 "      <xsd:element name=\"umlaut\" type=\"docCharType\" />\n"
 "      <xsd:element name=\"acute\" type=\"docCharType\" />\n"
 "      <xsd:element name=\"grave\" type=\"docCharType\" />\n"
