@@ -2,7 +2,7 @@
  *
  * $Id: entry.h,v 1.36 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -270,6 +270,7 @@ class Entry
     int  initLines;           //!< define/variable initializer lines to show 
     bool subGrouping;         //!< automatically group class members?
     bool callGraph;           //!< do we need to draw the call graph?
+    bool callerGraph;         //!< do we need to draw the caller graph?
     Specifier    virt;        //!< virtualness of the entry 
     Entry       *parent;      //!< parent node in the tree
     QCString	 type;        //!< member type 
@@ -310,6 +311,7 @@ class Entry
     TagInfo    *tagInfo;      //!< tag file info
     static int  num;          //!< counts the total number of entries
     bool        objc;         //!< Objective-C construct
+    bool        hidden;       //!< does this represent an entity this is hidden from the output
     enum 
     {
       GROUPDOC_NORMAL,        //!< defgroup
