@@ -2,7 +2,7 @@
  *
  * $Id: filedef.cpp,v 1.55 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -234,7 +234,7 @@ void FileDef::writeDocumentation(OutputList &ol)
   }
   QCString title = docname+versionTitle;
   QCString pageTitle=theTranslator->trFileReference(docname);
-  startFile(ol,getOutputFileBase(),name(),pageTitle);
+  startFile(ol,getOutputFileBase(),name(),pageTitle,HLI_FileVisible);
 
   if (Config_getBool("SHOW_DIRECTORIES") && getDirDef())
   {
@@ -623,6 +623,7 @@ void FileDef::writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const
 /*! Write a source listing of this file to the output */
 void FileDef::writeSource(OutputList &ol)
 {
+  static bool filterSourceFiles = Config_getBool("FILTER_SOURCE_FILES");
   QCString title = docname;
   if (!fileVersion.isEmpty())
   {
@@ -630,7 +631,7 @@ void FileDef::writeSource(OutputList &ol)
   }
   QCString pageTitle = theTranslator->trSourceFile(title);
   ol.disableAllBut(OutputGenerator::Html);
-  startFile(ol,getSourceFileBase(),0,pageTitle);
+  startFile(ol,getSourceFileBase(),0,pageTitle,HLI_FileVisible);
 
   if (Config_getBool("SHOW_DIRECTORIES") && getDirDef())
   {
@@ -657,7 +658,7 @@ void FileDef::writeSource(OutputList &ol)
   pIntf->resetCodeParserState();
   ol.startCodeFragment();
   pIntf->parseCode(ol,0,
-            fileToString(absFilePath(),Config_getBool("FILTER_SOURCE_FILES")),
+            fileToString(absFilePath(),filterSourceFiles),
             FALSE,0,this
            );
   ol.endCodeFragment();
@@ -667,12 +668,13 @@ void FileDef::writeSource(OutputList &ol)
 
 void FileDef::parseSource()
 {
+  static bool filterSourceFiles = Config_getBool("FILTER_SOURCE_FILES");
   DevNullCodeDocInterface devNullIntf;
   ParserInterface *pIntf = Doxygen::parserManager->getParser(getDefFileExtension());
   pIntf->resetCodeParserState();
   pIntf->parseCode(
             devNullIntf,0,
-            fileToString(absFilePath(),Config_getBool("FILTER_SOURCE_FILES")),
+            fileToString(absFilePath(),filterSourceFiles),
             FALSE,0,this
            );
 }
@@ -1243,7 +1245,7 @@ void FileDef::acquireFileVersion()
   if (!vercmd.isEmpty()) 
   {
     msg("Version of %s : ",filepath.data());
-    FILE *f=popen("\""+vercmd+"\" \""+filepath+"\"","r");
+    FILE *f=popen(vercmd+" \""+filepath+"\"","r");
     if (!f)
     {
       err("Error: could not execute %s\n",vercmd.data());
