@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -105,6 +105,12 @@ void HtmlDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Reg:     m_t << "&reg;"; break;
     case DocSymbol::Apos:    m_t << "'"; break;
     case DocSymbol::Quot:    m_t << "\""; break;
+    case DocSymbol::Lsquo:   m_t << "&lsquo;"; break;
+    case DocSymbol::Rsquo:   m_t << "&rsquo;"; break;
+    case DocSymbol::Ldquo:   m_t << "&ldquo;"; break;
+    case DocSymbol::Rdquo:   m_t << "&rdquo;"; break;
+    case DocSymbol::Ndash:   m_t << "&ndash;"; break;
+    case DocSymbol::Mdash:   m_t << "&mdash;"; break;
     case DocSymbol::Uml:     m_t << "&" << s->letter() << "uml;"; break;
     case DocSymbol::Acute:   m_t << "&" << s->letter() << "acute;"; break;
     case DocSymbol::Grave:   m_t << "&" << s->letter() << "grave;"; break;
@@ -257,7 +263,7 @@ void HtmlDocVisitor::visit(DocInclude *inc)
   {
     case DocInclude::Include: 
       m_t << PREFRAG_START;
-      Doxygen::parserManager->getParser(m_langExt)
+      Doxygen::parserManager->getParser(inc->extension())
                             ->parseCode(m_ci,inc->context(),inc->text().latin1(),
                                         inc->isExample(),inc->exampleFile());
       m_t << PREFRAG_END;
@@ -267,7 +273,7 @@ void HtmlDocVisitor::visit(DocInclude *inc)
          m_t << PREFRAG_START;
          QFileInfo cfi( inc->file() );
          FileDef fd( cfi.dirPath(), cfi.fileName() );
-         Doxygen::parserManager->getParser(m_langExt)
+         Doxygen::parserManager->getParser(inc->extension())
                                ->parseCode(m_ci,inc->context(),
                                            inc->text().latin1(),
                                            inc->isExample(),
