@@ -2,7 +2,7 @@
  *
  * $Id: htmlgen.h,v 1.51 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -95,6 +95,8 @@ class HtmlGenerator : public OutputGenerator
     void endMemberHeader();
     void startMemberSubtitle();
     void endMemberSubtitle();
+    void startMemberDocList();
+    void endMemberDocList();
     void startMemberList();
     void endMemberList();
     void startAnonTypeScope(int) {}
