@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -36,7 +36,7 @@ static QString escapeLabelName(const char *s)
     switch (c)
     {
       case '%': result+="\\%"; break;
-      case '|': result+="\\texttt{\"|}"; break;
+      case '|': result+="\\tt{\"|}"; break;
       case '!': result+="\"!"; break;
       default: result+=c;
     }
@@ -69,7 +69,7 @@ QString LatexDocVisitor::escapeMakeIndexChars(const char *s)
       case '!': m_t << "\"!"; break;
       case '"': m_t << "\"\""; break;
       case '@': m_t << "\"@"; break;
-      case '|': m_t << "\\texttt{\"|}"; break;
+      case '|': m_t << "\\tt{\"|}"; break;
       case '[': m_t << "["; break;
       case ']': m_t << "]"; break;
       default:  str[0]=c; filter(str); break;
@@ -136,7 +136,13 @@ void LatexDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Tm:      m_t << "\\texttrademark"; break;
     case DocSymbol::Reg:     m_t << "\\textregistered"; break;
     case DocSymbol::Apos:    m_t << "'"; break;
-    case DocSymbol::Quot:    m_t << "''"; break;
+    case DocSymbol::Quot:    m_t << "\""; break;
+    case DocSymbol::Lsquo:   m_t << "`"; break;
+    case DocSymbol::Rsquo:   m_t << "'"; break;
+    case DocSymbol::Ldquo:   m_t << "``"; break;
+    case DocSymbol::Rdquo:   m_t << "''"; break;
+    case DocSymbol::Ndash:   m_t << "--"; break;
+    case DocSymbol::Mdash:   m_t << "---"; break;
     case DocSymbol::Uml:     
                              if (s->letter()=='i') 
                                m_t << "\\\"{\\i}"; 
@@ -167,7 +173,7 @@ void LatexDocVisitor::visit(DocSymbol *s)
                                m_t << s->letter();
                              break;
     case DocSymbol::Tilde:   m_t << "\\~{"  << s->letter() << "}"; break;
-    case DocSymbol::Szlig:   m_t << "\"s"; break;
+    case DocSymbol::Szlig:   m_t << "{\\ss}"; break;
     case DocSymbol::Cedil:   m_t << "\\c{" << s->letter() << "}"; break;
     case DocSymbol::Ring:    m_t << "\\" << s->letter() << s->letter(); break;
     case DocSymbol::Nbsp:    m_t << "~"; break;
@@ -185,7 +191,7 @@ void LatexDocVisitor::visit(DocURL *u)
     if (u->isEmail()) m_t << "mailto:";
     m_t << u->url() << "}";
   }
-  m_t << "{\\tt ";
+  m_t << "\\tt{";
   filter(u->url());
   m_t << "}";
 }
@@ -251,11 +257,11 @@ void LatexDocVisitor::visit(DocVerbatim *s)
   switch(s->type())
   {
     case DocVerbatim::Code: 
-      m_t << "\n\n\\footnotesize\\begin{verbatim}"; 
+      m_t << "\n\n\\begin{Code}\\begin{verbatim}"; 
       Doxygen::parserManager->getParser(m_langExt)
                             ->parseCode(m_ci,s->context(),s->text().latin1(),
                                         s->isExample(),s->exampleFile());
-      m_t << "\\end{verbatim}\n\\normalsize" << endl; 
+      m_t << "\\end{verbatim}\\end{Code}\n" << endl; 
       break;
     case DocVerbatim::Verbatim: 
       m_t << "\n\n\\footnotesize\\begin{verbatim}"; 
@@ -316,33 +322,33 @@ void LatexDocVisitor::visit(DocInclude *inc)
   {
     case DocInclude::IncWithLines:
       { 
-         m_t << "\n\n\\footnotesize\\begin{verbatim}"; 
+         m_t << "\n\n\\begin{DocInclude}\\begin{verbatim}"; 
          QFileInfo cfi( inc->file() );
          FileDef fd( cfi.dirPath(), cfi.fileName() );
-         Doxygen::parserManager->getParser(m_langExt)
+         Doxygen::parserManager->getParser(inc->extension())
                                ->parseCode(m_ci,inc->context(),
                                            inc->text().latin1(),
                                            inc->isExample(),
                                            inc->exampleFile(), &fd);
-         m_t << "\\end{verbatim}\n\\normalsize" << endl; 
+         m_t << "\\end{verbatim}\n\\end{DocInclude}" << endl; 
       }
       break;    
     case DocInclude::Include: 
-      m_t << "\n\n\\footnotesize\\begin{verbatim}"; 
-      Doxygen::parserManager->getParser(m_langExt)
+      m_t << "\n\n\\begin{DocInclude}\\begin{verbatim}"; 
+      Doxygen::parserManager->getParser(inc->extension())
                             ->parseCode(m_ci,inc->context(),
                                         inc->text().latin1(),inc->isExample(),
                                         inc->exampleFile());
-      m_t << "\\end{verbatim}\n\\normalsize" << endl; 
+      m_t << "\\end{verbatim}\n\\end{DocInclude}" << endl; 
       break;
     case DocInclude::DontInclude: 
       break;
     case DocInclude::HtmlInclude: 
       break;
     case DocInclude::VerbInclude: 
-      m_t << "\n\n\\footnotesize\\begin{verbatim}"; 
+      m_t << "\n\n\\begin{VerbInclude}\\begin{verbatim}"; 
       m_t << inc->text();
-      m_t << "\\end{verbatim}\n\\normalsize" << endl; 
+      m_t << "\\end{verbatim}\n\\end{VerbInclude}" << endl; 
       break;
   }
 }
@@ -353,7 +359,7 @@ void LatexDocVisitor::visit(DocIncOperator *op)
   //    op->type(),op->isFirst(),op->isLast(),op->text().data());
   if (op->isFirst()) 
   {
-    if (!m_hide) m_t << "\n\n\\footnotesize\\begin{verbatim}"; 
+    if (!m_hide) m_t << "\n\n\\begin{DocInclude}\\begin{verbatim}"; 
     pushEnabled();
     m_hide = TRUE;
   }
@@ -372,7 +378,7 @@ void LatexDocVisitor::visit(DocIncOperator *op)
   if (op->isLast())  
   {
     popEnabled();
-    if (!m_hide) m_t << "\\end{verbatim}\n\\normalsize" << endl; 
+    if (!m_hide) m_t << "\\end{verbatim}\n\\end{DocInclude}" << endl; 
   }
   else
   {
@@ -740,12 +746,12 @@ void LatexDocVisitor::visitPre(DocImage *img)
     if (m_hide) return;
     if (img->hasCaption())
     {
-      m_t << "\\begin{figure}[H]" << endl;
+      m_t << "\\begin{Image}" << endl;
       m_t << "\\begin{center}" << endl;
     }
     else
     {
-      m_t << "\\mbox{";
+      m_t << "\\begin{ImageNoCaption}\\mbox{";
     }
     QString gfxName = img->name();
     if (gfxName.right(4)==".eps" || gfxName.right(4)==".pdf")
@@ -783,7 +789,10 @@ void LatexDocVisitor::visitPost(DocImage *img)
     if (img->hasCaption())
     {
       m_t << "\\end{center}" << endl;
-      m_t << "\\end{figure}" << endl;
+      m_t << "\\end{Image}" << endl;
+    }
+    else{
+      m_t << "\\end{ImageNoCaption}" << endl;
     }
   }
   else // other format
@@ -963,7 +972,7 @@ void LatexDocVisitor::visitPre(DocXRefItem *x)
   }
   else
   {
-    m_t << "{\\bf ";
+    m_t << "\\bf{";
   }
   m_insideItem=TRUE;
   filter(x->title());
@@ -1019,11 +1028,10 @@ void LatexDocVisitor::startLink(const QString &ref,const QString &file,const QSt
     if (!file.isEmpty() && !anchor.isEmpty()) m_t << "_";
     if (!anchor.isEmpty()) m_t << anchor;
     m_t << "}{";
-
   }
   else
   {
-    m_t << "{\\bf ";
+    m_t << "\\doxyref{";
   }
 }
 
@@ -1032,11 +1040,11 @@ void LatexDocVisitor::endLink(const QString &ref,const QString &file,const QStri
   m_t << "}";
   if (ref.isEmpty() && !Config_getBool("PDF_HYPERLINKS"))
   {
-    m_t << "{\\rm ("; 
+    m_t << "{"; 
     filter(theTranslator->trPageAbbreviation());
-    m_t << "\\,\\pageref{" << file;
+    m_t << "}{" << file;
     if (!anchor.isEmpty()) m_t << "_" << anchor;
-    m_t << "})}";
+    m_t << "}";
   }
 }
 
@@ -1078,12 +1086,12 @@ void LatexDocVisitor::startDotFile(const QString &fileName,
   writeDotGraphFromFile(name,outDir,baseName,EPS);
   if (hasCaption)
   {
-    m_t << "\\begin{figure}[H]" << endl;
+    m_t << "\\begin{Image}" << endl;
     m_t << "\\begin{center}" << endl;
   }
   else
   {
-    m_t << "\\mbox{";
+    m_t << "\\begin{ImageNoCaption}\\mbox{";
   }
   m_t << "\\includegraphics";
   if (!width.isEmpty())
@@ -1105,11 +1113,15 @@ void LatexDocVisitor::startDotFile(const QString &fileName,
 void LatexDocVisitor::endDotFile(bool hasCaption)
 {
   if (m_hide) return;
-  m_t << "}" << endl; // end mbox or caption
+  m_t << "}" << endl; // end caption or mbox
   if (hasCaption)
   {
     m_t << "\\end{center}" << endl;
-    m_t << "\\end{figure}" << endl;
+    m_t << "\\end{Image}" << endl;
+  }
+  else
+  {
+    m_t << "\\end{ImageNoCaption}" << endl;
   }
 }
 
