@@ -2,7 +2,7 @@
  *
  * $Id: latexgen.cpp,v 1.58 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -63,7 +63,7 @@ static QCString escapeLabelName(const char *s)
     switch (c)
     {
       case '%': result+="\\%"; break;
-      case '|': result+="\\texttt{\"|}"; break;
+      case '|': result+="\\tt{\"|}"; break;
       case '!': result+="\"!"; break;
       default: result+=c;
     }
@@ -85,7 +85,7 @@ static QCString escapeMakeIndexChars(LatexGenerator *g,QTextStream &t,const char
       case '!': t << "\"!"; break;
       case '"': t << "\"\""; break;
       case '@': t << "\"@"; break;
-      case '|': t << "\\texttt{\"|}"; break;
+      case '|': t << "\\tt{\"|}"; break;
       case '[': t << "["; break;
       case ']': t << "]"; break;
       default:  str[0]=c; g->docify(str); break;
@@ -133,7 +133,7 @@ void LatexGenerator::init()
   QTextStream t(&file);
   if (!Config_getBool("USE_PDFLATEX")) // use plain old latex
   {
-    t << "all clean: refman.dvi" << endl
+    t << "all: clean refman.dvi" << endl
       << endl
       << "ps: refman.ps" << endl
       << endl
@@ -182,11 +182,11 @@ void LatexGenerator::init()
   }
   else // use pdflatex for higher quality output
   {
-    t << "all clean: refman.pdf" << endl << endl;
+    t << "all: clean refman.pdf" << endl << endl;
     t << "refman.pdf: refman.tex" << endl;
     t << "\tpdflatex refman.tex" << endl;
     t << "\tmakeindex refman.idx" << endl;
-    t << "\tpdflatex refman.tex" << endl << endl
+    t << "\tpdflatex refman.tex" << endl
       << "\tlatex_count=5 ; \\" << endl
       << "\twhile egrep -s 'Rerun (LaTeX|to get cross-references right)' refman.log && [ $$latex_count -gt 0 ] ;\\" << endl
       << "\t    do \\" << endl
@@ -335,13 +335,27 @@ static void writeDefaultStyleSheetPart3(QTextStream &t)
 {
   t << "}}\n";
   t << "\\cfoot{}\n";
+  t << "\\newenvironment{Code}\n";
+  t << "{\\footnotesize}\n";
+  t << "{\\normalsize}\n";
+  t << "\\newcommand{\\doxyref}[3]{\\textbf{#1} (\\textnormal{#2}\\,\\pageref{#3})}\n";
+  t << "\\newenvironment{DocInclude}\n";
+  t << "{\\footnotesize}\n";
+  t << "{\\normalsize}\n";
+  t << "\\newenvironment{VerbInclude}\n";
+  t << "{\\footnotesize}\n";
+  t << "{\\normalsize}\n";
+  t << "\\newenvironment{Image}\n";
+  t << "{\\begin{figure}[H]}\n";
+  t << "{\\end{figure}}\n";
+  t << "\\newenvironment{ImageNoCaption}{}{}\n";
   t << "\\newenvironment{CompactList}\n";
   t << "{\\begin{list}{}{\n";
   t << "  \\setlength{\\leftmargin}{0.5cm}\n";
   t << "  \\setlength{\\itemsep}{0pt}\n";
   t << "  \\setlength{\\parsep}{0pt}\n";
   t << "  \\setlength{\\topsep}{0pt}\n";
-  t << "  \\renewcommand{\\makelabel}{}}}\n";
+  t << "  \\renewcommand{\\makelabel}{\\hfill}}}\n";
   t << "{\\end{list}}\n";
   t << "\\newenvironment{CompactItemize}\n";
   t << "{\n";
@@ -363,7 +377,7 @@ static void writeDefaultStyleSheetPart3(QTextStream &t)
   t << "}\n";
   t << "{\\end{tabular*}\\par}\n";
   t << "\\newcommand{\\entrylabel}[1]{\n";
-  t << "   {\\parbox[b]{\\labelwidth-4pt}{\\makebox[0pt][l]{\\textbf{#1}}\\\\}}}\n";
+  t << "   {\\parbox[b]{\\labelwidth-4pt}{\\makebox[0pt][l]{\\textbf{#1}}\\vspace{1.5\\baselineskip}}}}\n";
   t << "\\newenvironment{Desc}\n";
   t << "{\\begin{list}{}\n";
   t << "  {\n";
@@ -411,12 +425,12 @@ void LatexGenerator::writeStyleSheetFile(QFile &f)
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2005";
+  //t << "Dimitri van Heesch \\copyright~1997-2006";
   writeDefaultStyleSheetPart2(t);
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2005";
+  //t << "Dimitri van Heesch \\copyright~1997-2006";
   writeDefaultStyleSheetPart3(t);
 }
 
@@ -831,14 +845,14 @@ void LatexGenerator::writeStyleInfo(int part)
       break;
     case 2:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2005";
+        //t << " Dimitri van Heesch \\copyright~1997-2006";
         t << "}]{}\n";
         writeDefaultStyleSheetPart2(t);
       }
       break;
     case 4:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2005";
+        //t << " Dimitri van Heesch \\copyright~1997-2006";
         writeDefaultStyleSheetPart3(t);
         endPlainFile();
       }
@@ -910,7 +924,7 @@ void LatexGenerator::endHtmlLink()
 void LatexGenerator::writeStartAnnoItem(const char *,const char *,
                                         const char *path,const char *name)
 {
-  t << "\\item\\contentsline{section}{{\\bf ";
+  t << "\\item\\contentsline{section}{\\bf ";
   if (path) docify(path);
   docify(name); 
   t << "} ";
@@ -945,7 +959,7 @@ void LatexGenerator::endIndexValue(const char *name,bool hasBrief)
 //void LatexGenerator::writeClassLink(const char *,const char *,
 //                                    const char *,const char *name)
 //{
-//  t << "{\\bf ";
+//  t << "{\\bf";
 //  docify(name);
 //  t << "}"; 
 //}
@@ -985,7 +999,7 @@ void LatexGenerator::writeObjectLink(const char *ref, const char *f,
   }
   else
   {
-    t << "{\\bf ";
+    t << "\\bf{";
     docify(text);
     t << "}";
   } 
@@ -993,15 +1007,15 @@ void LatexGenerator::writeObjectLink(const char *ref, const char *f,
 
 void LatexGenerator::startPageRef()
 {
-  t << " {\\rm (";
+  t << " \\doxyref{";
 }
 
 void LatexGenerator::endPageRef(const char *clname, const char *anchor)
 {
-  t << "\\,\\pageref{";
+  t << "}{";
   if (clname) t << clname; 
   if (anchor) t << "_" << anchor;
-  t << "})}";
+  t << "}";
 }
 
 void LatexGenerator::writeCodeLink(const char *,const char *,
