@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -17,6 +17,7 @@
 
 #include <stdio.h>
 #include <qregexp.h>
+#include <md5.h>
 #include "memberdef.h"
 #include "membername.h"
 #include "doxygen.h"
@@ -33,6 +34,7 @@
 #include "docparser.h"
 #include "dot.h"
 #include "searchindex.h"
+#include "parserintf.h"
 
 //-----------------------------------------------------------------------------
 
@@ -77,7 +79,7 @@ static QCString addTemplateNames(const QCString &s,const QCString &n,const QCStr
 static bool writeDefArgumentList(OutputList &ol,ClassDef *cd,
                                  const QCString & /*scopeName*/,MemberDef *md)
 {
-  ArgumentList *defArgList=md->isDocsForDefinition() ? 
+  ArgumentList *defArgList=(md->isDocsForDefinition() && !md->isProperty()) ? 
                              md->argumentList() : md->declArgumentList();
   //printf("writeDefArgumentList `%s' isDocsForDefinition()=%d\n",md->name().data(),md->isDocsForDefinition());
   if (defArgList==0) 
@@ -232,11 +234,13 @@ static bool writeDefArgumentList(OutputList &ol,ClassDef *cd,
     first=FALSE;
   }
   ol.pushGeneratorState();
+  bool htmlOn = ol.isEnabled(OutputGenerator::Html);
   ol.disable(OutputGenerator::Html);
   //if (!first) ol.writeString("&nbsp;");
   if (!md->isObjCMethod()) ol.docify(")"); // end argument list
   ol.enableAll();
   ol.disableAllBut(OutputGenerator::Html);
+  if (!htmlOn) ol.disable(OutputGenerator::Html);
   if (!md->isDefine()) 
   {
     if (first) ol.startParameterName(defArgList->count()<2);
@@ -329,12 +333,13 @@ MemberDef::MemberDef(const char *df,int dl,
   //membTAL=0;
   m_defTmpArgLists=0;
   m_hasCallGraph = FALSE;
+  m_hasCallerGraph = FALSE;
   initLines=0;
   type=t;
-  if (mt==Typedef && type.left(8)=="typedef ") type=type.mid(8);
-  if (type.left(7)=="struct ") type=type.right(type.length()-7);
-  if (type.left(6)=="class " ) type=type.right(type.length()-6);
-  if (type.left(6)=="union " ) type=type.right(type.length()-6);
+  if (mt==Typedef) type.stripPrefix("typedef ");
+  type.stripPrefix("struct ");
+  type.stripPrefix("class " );
+  type.stripPrefix("union " );
   type=removeRedundantWhiteSpace(type);
 
   args=a;
@@ -426,6 +431,7 @@ MemberDef::MemberDef(const char *df,int dl,
   m_hasDocumentedParams = FALSE;
   m_hasDocumentedReturnType = FALSE;
   m_docProvider = 0;
+  m_isDMember = m_defFileName.right(2).lower()==".d";
 }
 
 /*! Destroys the member definition. */
@@ -506,31 +512,53 @@ bool MemberDef::hasExamples()
 
 QCString MemberDef::getOutputFileBase() const
 {
-  if (m_templateMaster)
+  static bool separateMemberPages = Config_getBool("SEPARATE_MEMBER_PAGES");
+  QCString baseName;
+  if (explicitOutputFileBase)
+  {
+    return explicitOutputFileBase;
+  }
+  else if (m_templateMaster)
   {
     return m_templateMaster->getOutputFileBase();
   }
   else if (group)
   {
-    return group->getOutputFileBase();
+    baseName=group->getOutputFileBase();
   }
   else if (classDef)
   {
-    return classDef->getOutputFileBase();
+    baseName=classDef->getOutputFileBase();
   }
   else if (nspace)
   {
-    return nspace->getOutputFileBase();
+    baseName=nspace->getOutputFileBase();
   }
   else if (fileDef)
   {
-    return fileDef->getOutputFileBase();
+    baseName=fileDef->getOutputFileBase();
   }
-  warn(m_defFileName,m_defLine,
+  
+  if (baseName.isEmpty())
+  {
+    warn(m_defFileName,m_defLine,
        "Warning: Internal inconsistency: member %s does not belong to any"
        " container!",name().data()
       );
-  return "dummy";
+    return "dummy";
+  }
+  else if (separateMemberPages)
+  {
+    if (getEnumScope()) // enum value, which is part of enum's documentation
+    {
+      baseName+="_"+getEnumScope()->anchor();
+    }
+    else
+    {
+      baseName+="_"+anchor();
+    }
+  }
+  return baseName;
 }
 
 QCString MemberDef::getReference() const
@@ -580,6 +608,8 @@ QCString MemberDef::anchor() const
 
 bool MemberDef::isLinkableInProject() const
 {
+  static bool extractPrivate = Config_getBool("EXTRACT_PRIVATE");
+  static bool extractStatic  = Config_getBool("EXTRACT_STATIC");
   //printf("MemberDef::isLinkableInProject(name=%s)\n",name().data());
   if (m_templateMaster)
   {
@@ -610,17 +640,17 @@ bool MemberDef::isLinkableInProject() const
     //printf("in a namespace but namespace not linkable!\n");
     return FALSE; // in namespace but namespace not linkable
   }
-  if (!group && !nspace && !related && fileDef && !fileDef->isLinkableInProject()) 
+  if (!group && !nspace && !related && !classDef && fileDef && !fileDef->isLinkableInProject()) 
   {
     //printf("in a file but file not linkable!\n");
     return FALSE; // in file (and not in namespace) but file not linkable
   }
-  if (prot==Private && !Config_getBool("EXTRACT_PRIVATE") && mtype!=Friend) 
+  if (prot==Private && !extractPrivate && mtype!=Friend) 
   {
     //printf("private and invisible!\n");
     return FALSE; // hidden due to protection
   }
-  if (isStatic() && classDef==0 && !Config_getBool("EXTRACT_STATIC")) 
+  if (isStatic() && classDef==0 && !extractStatic) 
   {
     //printf("static and invisible!\n");
     return FALSE; // hidden due to staticness
@@ -652,13 +682,37 @@ void MemberDef::setDefinitionTemplateParameterLists(QList<ArgumentList> *lists)
 }
 
 void MemberDef::writeLink(OutputList &ol,ClassDef *,NamespaceDef *,
-                      FileDef *,GroupDef *gd)
+                      FileDef *fd,GroupDef *gd,bool onlyText)
 {
   QCString sep = Config_getBool("OPTIMIZE_OUTPUT_JAVA") ? "." : "::";
   QCString n = name();
   if (classDef && gd) n.prepend(classDef->name()+sep);
-  else if (nspace && gd) n.prepend(nspace->name()+sep);
-  ol.writeObjectLink(getReference(),getOutputFileBase(),anchor(),n);
+  else if (nspace && (gd || fd)) n.prepend(nspace->name()+sep);
+  if (isObjCMethod())
+  {
+    if (isStatic()) ol.docify("+ "); else ol.docify("- ");
+  }
+  if (!onlyText) // write link
+  {
+    if (mtype==EnumValue && getGroupDef()==0 &&          // enum value is not grouped
+        getEnumScope() && getEnumScope()->getGroupDef()) // but its container is
+    {
+      GroupDef *enumValGroup = getEnumScope()->getGroupDef();
+      ol.writeObjectLink(enumValGroup->getReference(),
+                         enumValGroup->getOutputFileBase(),
+                         anchor(),n);
+    }
+    else
+    {
+      ol.writeObjectLink(getReference(),getOutputFileBase(),anchor(),n);
+    }
+  }
+  else // write only text
+  {
+    ol.startBold();
+    ol.docify(n);
+    ol.endBold();
+  }
 }
 
 /*! If this member has an anonymous class/struct/union as its type, then
@@ -681,7 +735,7 @@ ClassDef *MemberDef::getClassDefOfAnonymousType()
   // strip `static' keyword from ltype
   //if (ltype.left(7)=="static ") ltype=ltype.right(ltype.length()-7);
   // strip `friend' keyword from ltype
-  if (ltype.left(7)=="friend ") ltype=ltype.right(ltype.length()-7);
+  ltype.stripPrefix("friend ");
   static QRegExp r("@[0-9]+");
   int l,i=r.match(ltype,0,&l);
   //printf("ltype=`%s' i=%d\n",ltype.data(),i);
@@ -721,6 +775,13 @@ ClassDef *MemberDef::getClassDefOfAnonymousType()
  */
 bool MemberDef::isBriefSectionVisible() const
 {
+    static bool extractStatic       = Config_getBool("EXTRACT_STATIC");
+    static bool hideUndocMembers    = Config_getBool("HIDE_UNDOC_MEMBERS");
+    static bool briefMemberDesc     = Config_getBool("BRIEF_MEMBER_DESC");
+    static bool repeatBrief         = Config_getBool("REPEAT_BRIEF");
+    static bool hideFriendCompounds = Config_getBool("HIDE_FRIEND_COMPOUNDS");
+    static bool extractPrivate      = Config_getBool("EXTRACT_PRIVATE");
+
     //printf("Member %s grpId=%d docs=%s file=%s args=%s\n",
     //    name().data(),
     //    0,"", //grpId,grpId==-1?"<none>":Doxygen::memberDocDict[grpId]->data(),
@@ -737,26 +798,26 @@ bool MemberDef::isBriefSectionVisible() const
     // explicitly enabled in the config file
     bool visibleIfStatic = !(getClassDef()==0 && 
                              isStatic() && 
-                             !Config_getBool("EXTRACT_STATIC")
+                             !extractStatic
                             );
 
     // only include members is the are documented or 
     // HIDE_UNDOC_MEMBERS is NO in the config file
-    bool visibleIfDocumented = (!Config_getBool("HIDE_UNDOC_MEMBERS") || 
+    bool visibleIfDocumented = (!hideUndocMembers || 
                                 hasDocs || 
                                 isDocumentedFriendClass()
                                );
 
     // hide members with no detailed description and brief descriptions 
     // explicitly disabled.
-    bool visibleIfEnabled = !(Config_getBool("HIDE_UNDOC_MEMBERS") && 
+    bool visibleIfEnabled = !(hideUndocMembers && 
                               documentation().isEmpty() &&
-                              !Config_getBool("BRIEF_MEMBER_DESC") && 
-                              !Config_getBool("REPEAT_BRIEF")
+                              !briefMemberDesc && 
+                              !repeatBrief
                              );
 
     // Hide friend (class|struct|union) declarations if HIDE_FRIEND_COMPOUNDS is true
-    bool visibleIfFriendCompound = !(Config_getBool("HIDE_FRIEND_COMPOUNDS") &&
+    bool visibleIfFriendCompound = !(hideFriendCompounds &&
                                      isFriend() &&
                                      (type=="friend class" || 
                                       type=="friend struct" ||
@@ -767,7 +828,7 @@ bool MemberDef::isBriefSectionVisible() const
     // only include members that are non-private unless EXTRACT_PRIVATE is
     // set to YES or the member is part of a group
     bool visibleIfPrivate = (protection()!=Private || 
-                             Config_getBool("EXTRACT_PRIVATE") ||
+                             extractPrivate ||
                              mtype==Friend
                             );
     
@@ -816,6 +877,10 @@ void MemberDef::writeDeclaration(OutputList &ol,
   // hide members whose brief section should not be visible
   //if (!isBriefSectionVisible()) return;
 
+  Definition *d=0;
+  ASSERT (cd!=0 || nd!=0 || fd!=0 || gd!=0); // member should belong to something
+  if (cd) d=cd; else if (nd) d=nd; else if (fd) d=fd; else d=gd;
+
   // write tag file information of this member
   if (!Config_getString("GENERATE_TAGFILE").isEmpty())
   {
@@ -856,6 +921,7 @@ void MemberDef::writeDeclaration(OutputList &ol,
     Doxygen::tagFile << "\">" << endl;
     Doxygen::tagFile << "      <type>" << convertToXML(typeString()) << "</type>" << endl;
     Doxygen::tagFile << "      <name>" << convertToXML(name()) << "</name>" << endl;
+    Doxygen::tagFile << "      <anchorfile>" << convertToXML(getOutputFileBase()+Doxygen::htmlFileExtension) << "</anchorfile>" << endl;
     Doxygen::tagFile << "      <anchor>" << convertToXML(anchor()) << "</anchor>" << endl;
     Doxygen::tagFile << "      <arglist>" << convertToXML(argsString()) << "</arglist>" << endl;
     writeDocAnchorsToTagFile();
@@ -870,16 +936,12 @@ void MemberDef::writeDeclaration(OutputList &ol,
     Doxygen::searchIndex->addWord(qualifiedName(),FALSE);
   }
 
-  Definition *d=0;
-  ASSERT (cd!=0 || nd!=0 || fd!=0 || gd!=0); // member should belong to something
-  if (cd) d=cd; else if (nd) d=nd; else if (fd) d=fd; else d=gd;
   QCString cname  = d->name();
   QCString cfname = getOutputFileBase();
-  QCString osname = cname;
+  //QCString osname = cname;
   // in case of class members that are put in a group the name of the outerscope
   // differs from the cname.
-  if (getOuterScope()) osname=getOuterScope()->name();
-
+  //if (getOuterScope()) osname=getOuterScope()->name();
 
   HtmlHelp *htmlHelp=0;
   bool hasHtmlHelp = Config_getBool("GENERATE_HTML") && Config_getBool("GENERATE_HTMLHELP");
@@ -899,7 +961,8 @@ void MemberDef::writeDeclaration(OutputList &ol,
   {
     QCString doxyName=name().copy();
     if (!cname.isEmpty()) doxyName.prepend(cname+"::");
-    ol.startDoxyAnchor(cfname,cname,anchor(),doxyName);
+    QCString doxyArgs=argsString();
+    ol.startDoxyAnchor(cfname,cname,anchor(),doxyName,doxyArgs);
 
     ol.pushGeneratorState();
     ol.disable(OutputGenerator::Man);
@@ -917,6 +980,7 @@ void MemberDef::writeDeclaration(OutputList &ol,
     }
   }
 
+  // *** write template lists
   if (tArgList)
   {
     if (!isAnonymous) ol.startMemberTemplateParams();
@@ -924,12 +988,11 @@ void MemberDef::writeDeclaration(OutputList &ol,
     if (!isAnonymous) ol.endMemberTemplateParams();
   }
 
+  // *** write type
   QCString ltype(type);
   if (mtype==Typedef) ltype.prepend("typedef ");
-  // strip `static' keyword from ltype
-  //if (ltype.left(7)=="static ") ltype=ltype.right(ltype.length()-7);
   // strip `friend' keyword from ltype
-  if (ltype.left(7)=="friend ") ltype=ltype.right(ltype.length()-7);
+  ltype.stripPrefix("friend ");
   static QRegExp r("@[0-9]+");
 
   bool endAnonScopeNeeded=FALSE;
@@ -977,6 +1040,10 @@ void MemberDef::writeDeclaration(OutputList &ol,
       }
     }
   }
+  else if (ltype=="@") // rename type from enum values
+  {
+    ltype="";
+  }
   else
   {
     if (isObjCMethod())
@@ -1009,7 +1076,7 @@ void MemberDef::writeDeclaration(OutputList &ol,
     ol.insertMemberAlign(tArgList!=0);
   }
 
-  // write name
+  // *** write name
   if (!name().isEmpty() && name().at(0)!='@') // hide annonymous stuff 
   {
     //printf("Member name=`%s gd=%p md->groupDef=%p inGroup=%d isLinkable()=%d\n",name().data(),gd,getGroupDef(),inGroup,isLinkable());
@@ -1049,12 +1116,13 @@ void MemberDef::writeDeclaration(OutputList &ol,
       // descriptions are enabled or there is no detailed description.
     {
       if (annMemb) annMemb->annUsed=annUsed=TRUE;
-      ol.startBold();
-      ol.docify(name());
-      ol.endBold();
+      ClassDef *rcd = cd;
+      if (isReference() && classDef) rcd = classDef; 
+      writeLink(ol,rcd,nd,fd,gd,TRUE);
     }
   }
 
+  // *** write arguments
   if (argsString() && !isObjCMethod()) 
   {
     if (!isDefine()) ol.writeString(" ");
@@ -1062,12 +1130,14 @@ void MemberDef::writeDeclaration(OutputList &ol,
     linkifyText(TextGeneratorOLImpl(ol),d,getBodyDef(),name(),argsString()); 
   }
 
+  // *** write exceptions
   if (excpString())
   {
     ol.writeString(" ");
     ol.docify(excpString());
   }
 
+  // *** write bitfields
   if (!bitfields.isEmpty()) // add bitfields
   {
     linkifyText(TextGeneratorOLImpl(ol),d,getBodyDef(),name(),bitfields.simplifyWhiteSpace());
@@ -1088,6 +1158,7 @@ void MemberDef::writeDeclaration(OutputList &ol,
       linkifyText(TextGeneratorOLImpl(ol),d,getBodyDef(),name(),init);
     }
   }
+
   if (isObjCMethod() && isImplementation())
   {
     ol.startTypewriter();
@@ -1095,6 +1166,25 @@ void MemberDef::writeDeclaration(OutputList &ol,
     ol.endTypewriter();
   }
 
+  if (isProperty())
+  {
+      ol.writeLatexSpacing();
+      ol.startTypewriter();
+      ol.docify(" [");
+      QStrList sl;
+      if (isGettable()) sl.append("get");
+      if (isSettable()) sl.append("set");
+      const char *s=sl.first();
+      while (s)
+      {
+         ol.docify(s);
+         s=sl.next();
+         if (s) ol.docify(", ");
+      }
+      ol.docify("]");
+      ol.endTypewriter();
+  }
+
   if (!detailsVisible && !annMemb)
   {
     ol.endDoxyAnchor(cfname,anchor());
@@ -1139,10 +1229,18 @@ void MemberDef::writeDeclaration(OutputList &ol,
 
 bool MemberDef::isDetailedSectionLinkable() const          
 { 
+  static bool extractAll        = Config_getBool("EXTRACT_ALL");
+  static bool alwaysDetailedSec = Config_getBool("ALWAYS_DETAILED_SEC");
+  static bool repeatBrief       = Config_getBool("REPEAT_BRIEF");
+  static bool briefMemberDesc   = Config_getBool("BRIEF_MEMBER_DESC");
+  static bool hideUndocMembers  = Config_getBool("HIDE_UNDOC_MEMBERS");
+  static bool extractStatic     = Config_getBool("EXTRACT_STATIC");
+  static bool extractPrivate    = Config_getBool("EXTRACT_PRIVATE");
+
   // the member has details documentation for any of the following reasons
   bool docFilter = 
          // treat everything as documented
-         Config_getBool("EXTRACT_ALL") ||          
+         extractAll ||          
          // has detailed docs
          !documentation().isEmpty() ||             
          // has inbody docs
@@ -1153,24 +1251,23 @@ bool MemberDef::isDetailedSectionLinkable() const
          (mtype==EnumValue && !briefDescription().isEmpty()) || 
          // has brief description that is part of the detailed description
          (!briefDescription().isEmpty() &&           // has brief docs
-          (Config_getBool("ALWAYS_DETAILED_SEC") &&  // they or visible in
-           Config_getBool("REPEAT_BRIEF") ||         // detailed section or
-           !Config_getBool("BRIEF_MEMBER_DESC")      // they are explicitly not
+          (alwaysDetailedSec &&  // they or visible in
+           repeatBrief ||        // detailed section or
+           !briefMemberDesc      // they are explicitly not
           )                                          // shown in brief section
          ) ||
          // has a multi-line initialization block
          //(initLines>0 && initLines<maxInitLines) || 
-         (hasMultiLineInitializer() && !Config_getBool("HIDE_UNDOC_MEMBERS")) ||
+         (hasMultiLineInitializer() && !hideUndocMembers) ||
          // has one or more documented arguments
          (defArgList!=0 && defArgList->hasDocumentation()); 
          
   // this is not a global static or global statics should be extracted
-  bool staticFilter = getClassDef()!=0 || !isStatic() || Config_getBool("EXTRACT_STATIC"); 
+  bool staticFilter = getClassDef()!=0 || !isStatic() || extractStatic; 
          
   // only include members that are non-private unless EXTRACT_PRIVATE is
   // set to YES or the member is part of a group
-  bool privateFilter = (protection()!=Private || 
-                           Config_getBool("EXTRACT_PRIVATE") ||
+  bool privateFilter = (protection()!=Private || extractPrivate ||
                            mtype==Friend
                           );
 
@@ -1192,11 +1289,13 @@ bool MemberDef::isDetailedSectionLinkable() const
   return ((docFilter && staticFilter && privateFilter && friendCompoundFilter) /*|| inAnonymousScope*/);
 }
 
-bool MemberDef::isDetailedSectionVisible(bool inGroup) const          
+bool MemberDef::isDetailedSectionVisible(bool inGroup,bool inFile) const          
 { 
   bool groupFilter = getGroupDef()==0 || inGroup; 
+  bool fileFilter  = getNamespaceDef()==0 || !inFile;
 
-  bool visible = isDetailedSectionLinkable() && groupFilter && !isReference();
+  bool visible = isDetailedSectionLinkable() && groupFilter && fileFilter && 
+                 !isReference();
   //printf("MemberDef::isDetailedSectionVisible() %d\n",visible);
   return visible;
 }
@@ -1207,22 +1306,28 @@ bool MemberDef::isDetailedSectionVisible(bool inGroup) const
 void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
                                    const char *scName,
                                    Definition *container,
-                                   bool inGroup
+                                   bool inGroup,
+                                   bool showEnumValues
                                   )
 {
   // if this member is in a group find the real scope name.
   bool hasParameterList = FALSE;
-  bool hasDocs = isDetailedSectionVisible(inGroup);
+  bool inFile = container->definitionType()==Definition::TypeFile;
+  bool hasDocs = isDetailedSectionVisible(inGroup,inFile);
   //printf("MemberDef::writeDocumentation(): name=`%s' hasDocs=`%d' containerType=%d inGroup=%d\n",
   //    name().data(),hasDocs,container->definitionType(),inGroup);
   if ( !hasDocs ) return;
+  if (isEnumValue() && !showEnumValues) return;
+
   QCString scopeName = scName;
   QCString memAnchor = anchor();
+  QCString ciname = container->name();
   if (container->definitionType()==TypeGroup)
   {
     if (getClassDef())          scopeName=getClassDef()->name();
     else if (getNamespaceDef()) scopeName=getNamespaceDef()->name();
     else if (getFileDef())      scopeName=getFileDef()->name();
+    ciname = ((GroupDef *)container)->groupTitle();
   }
   else if (container->definitionType()==TypeFile && getNamespaceDef())
   { // member is in a namespace, but is written as part of the file documentation
@@ -1231,21 +1336,29 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
   }
 
   QCString cname  = container->name();
-  QCString cfname = getOutputFileBase();  
+  QCString cfname = getOutputFileBase();
+  QCString cfiname = container->getOutputFileBase();
 
-  //ol.addIndexItem(name(),cname);
-  //ol.addIndexItem(cname,name());
-
-  if (Config_getBool("GENERATE_HTML") && Config_getBool("GENERATE_HTMLHELP"))
+  bool hasHtmlHelp = Config_getBool("GENERATE_HTML") && Config_getBool("GENERATE_HTMLHELP");
+  HtmlHelp *htmlHelp = 0;
+  if (hasHtmlHelp)
   {
-    HtmlHelp *htmlHelp = HtmlHelp::getInstance();
-    htmlHelp->addIndexItem(cname,name(),cfname,memAnchor);
+    if (isEnumerate() && name().at(0)=='@')
+    {
+      // don't add to index
+    }
+    else
+    {
+      htmlHelp = HtmlHelp::getInstance();
+      htmlHelp->addIndexItem(ciname,name(),cfiname,cfname,memAnchor);
+    }
   }
 
   // get member name
   QCString doxyName=name().copy();
   // prepend scope if there is any. TODO: make this optional for C only docs
   if (scopeName) doxyName.prepend((QCString)scopeName+"::");
+  QCString doxyArgs=argsString();
 
   QCString ldef = definition();
   //printf("member `%s' def=`%s'\n",name().data(),ldef.data());
@@ -1260,16 +1373,20 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
       ldef.prepend("enum ");
     }
   }
+  else if (isEnumValue())
+  {
+    if (ldef.at(0)=='@')
+    {
+      ldef=ldef.mid(2);
+    }
+  }
   int i=0,l;
   static QRegExp r("@[0-9]+");
 
-  if (isEnumValue()) return;
+  //----------------------------------------
 
   ol.pushGeneratorState();
 
-  bool hasHtmlHelp = Config_getBool("GENERATE_HTML") && Config_getBool("GENERATE_HTMLHELP");
-  HtmlHelp *htmlHelp = 0;
-  if (hasHtmlHelp) htmlHelp = HtmlHelp::getInstance();
 
   if ((isVariable() || isTypedef()) && (i=r.match(ldef,0,&l))!=-1)
   {
@@ -1281,12 +1398,8 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
     {
       if (vmd->isEnumerate() && ldef.mid(i,l)==vmd->name())
       {
-        ol.startDoxyAnchor(cfname,cname,memAnchor,doxyName);
+        ol.startDoxyAnchor(cfname,cname,memAnchor,doxyName,doxyArgs);
         ol.startMemberDoc(cname,name(),memAnchor,name());
-        if (hasHtmlHelp)
-        {
-          htmlHelp->addIndexItem(cname,name(),cfname,memAnchor);
-        }
         linkifyText(TextGeneratorOLImpl(ol),container,getBodyDef(),name(),ldef.left(i));
         vmd->writeEnumDeclaration(ol,getClassDef(),getNamespaceDef(),getFileDef(),getGroupDef());
         linkifyText(TextGeneratorOLImpl(ol),container,getBodyDef(),name(),ldef.right(ldef.length()-i-l));
@@ -1297,12 +1410,8 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
     if (!found) // anonymous compound
     {
       //printf("Anonymous compound `%s'\n",cname.data());
-      ol.startDoxyAnchor(cfname,cname,memAnchor,doxyName);
+      ol.startDoxyAnchor(cfname,cname,memAnchor,doxyName,doxyArgs);
       ol.startMemberDoc(cname,name(),memAnchor,name());
-      if (hasHtmlHelp)
-      {
-        htmlHelp->addIndexItem(cname,name(),cfname,memAnchor);
-      }
       // strip anonymous compound names from definition
       int si=ldef.find(' '),pi,ei=i+l;
       if (si==-1) si=0;
@@ -1319,12 +1428,8 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
   }
   else // not an enum value
   {
-    ol.startDoxyAnchor(cfname,cname,memAnchor,doxyName);
+    ol.startDoxyAnchor(cfname,cname,memAnchor,doxyName,doxyArgs);
     ol.startMemberDoc(cname,name(),memAnchor,name());
-    if (hasHtmlHelp)
-    {
-      htmlHelp->addIndexItem(cname,name(),cfname,memAnchor);
-    }
 
     ClassDef *cd=getClassDef();
     if (!Config_getBool("HIDE_SCOPE_NAMES"))
@@ -1375,6 +1480,7 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
         }
       }
     }
+
     ol.startMemberDocName(isObjCMethod());
     if (cd && cd->isObjectiveC())
     {
@@ -1408,7 +1514,9 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
       //printf("end   >%s< i=%d\n",ldef.data(),i);
       if (isStatic()) ldef.prepend("+ "); else ldef.prepend("- ");
     }
+
     linkifyText(TextGeneratorOLImpl(ol),container,getBodyDef(),name(),ldef);
+
     hasParameterList=writeDefArgumentList(ol,cd,scopeName,this);
     if (hasOneLineInitializer()) // add initializer
     {
@@ -1521,9 +1629,10 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
     else
       ol.parseText(theTranslator->trInitialValue());
     ol.endBold();
-    initParseCodeContext();
+    ParserInterface *pIntf = Doxygen::parserManager->getParser(getDefFileExtension());
+    pIntf->resetCodeParserState();
     ol.startCodeFragment();
-    parseCode(ol,scopeName,init,FALSE,0);
+    pIntf->parseCode(ol,scopeName,init,FALSE,0);
     ol.endCodeFragment();
   }
 
@@ -1599,6 +1708,7 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
     ol.endParamList();
   }
 
+  // For enum, we also write the documented enum values
   if (isEnumerate())
   {
     bool first=TRUE;
@@ -1621,13 +1731,13 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
           ol.addIndexItem(fmd->name(),cname);
           ol.addIndexItem(cname,fmd->name());
 
-          if (Config_getBool("GENERATE_HTML") && Config_getBool("GENERATE_HTMLHELP"))
+          if (hasHtmlHelp)
           {
-            HtmlHelp::getInstance()->addIndexItem(cname,fmd->name(),cfname,fmd->anchor());
+            HtmlHelp::getInstance()->addIndexItem(cname,fmd->name(),cfiname,cfname,fmd->anchor());
           }
           //ol.writeListItem();
           ol.startDescTableTitle(); // this enables emphasis!
-          ol.startDoxyAnchor(cfname,cname,fmd->anchor(),fmd->name());
+          ol.startDoxyAnchor(cfname,cname,fmd->anchor(),fmd->name(),fmd->argsString());
           first=FALSE;
           //ol.startEmphasis();
           ol.docify(fmd->name());
@@ -1750,7 +1860,7 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
       // write the list of classes that overwrite this member
       ol.disable(OutputGenerator::RTF);
       ol.newParagraph();
-      ol.enableAll();
+      ol.enable(OutputGenerator::RTF);
 
       QCString reimplInLine;
       if (virt==Pure || (classDef && classDef->compoundType()==ClassDef::Interface))
@@ -1800,6 +1910,7 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
       ol.parseText(reimplInLine.right(reimplInLine.length()-index));
     }
   }
+
   // write the list of examples that use this member
   if (hasExamples())
   {
@@ -1809,19 +1920,19 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
     //ol.endDescItem();
     ol.endSimpleSect();
   }
+
   // write reference to the source
   writeSourceDef(ol,cname);
   writeSourceRefs(ol,cname);
   writeSourceReffedBy(ol,cname);
   writeInlineCode(ol,cname);
 
-  ol.endIndent();
-
+  // write call graph
   if ((m_hasCallGraph || Config_getBool("CALL_GRAPH")) 
       && isFunction() && Config_getBool("HAVE_DOT")
      )
   {
-    DotCallGraph callGraph(this,Config_getInt("MAX_DOT_GRAPH_DEPTH"));
+    DotCallGraph callGraph(this,Config_getInt("MAX_DOT_GRAPH_DEPTH"), false);
     if (!callGraph.isTrivial())
     {
       msg("Generating call graph for function %s\n",qualifiedName().data());
@@ -1833,14 +1944,35 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
       ol.enableAll();
     }
   }
+  if ((m_hasCallerGraph || Config_getBool("CALLER_GRAPH")) 
+      && isFunction() && Config_getBool("HAVE_DOT")
+     )
+  {
+    DotCallGraph callerGraph(this,Config_getInt("MAX_DOT_GRAPH_DEPTH"), true);
+    if (!callerGraph.isTrivial())
+    {
+      msg("Generating caller graph for function %s\n",qualifiedName().data());
+      ol.disable(OutputGenerator::Man);
+      ol.newParagraph();
+      ol.startCallGraph();
+      ol.parseText(theTranslator->trCallerGraph());
+      ol.endCallGraph(callerGraph);
+      ol.enableAll();
+    }
+  }
+
+  ol.endIndent();
 
   // enable LaTeX again
   //if (Config_getBool("EXTRACT_ALL") && !hasDocs) ol.enable(OutputGenerator::Latex); 
   ol.popGeneratorState();
 
+  //------------------------------------------------
+
   if (!Config_getBool("EXTRACT_ALL") &&
       Config_getBool("WARN_IF_UNDOCUMENTED") &&
-      Config_getBool("WARN_NO_PARAMDOC"))
+      Config_getBool("WARN_NO_PARAMDOC") &&
+      !Doxygen::suppressDocWarnings)
   {
     if (!hasDocumentedParams())
     {
@@ -1858,6 +1990,27 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
 
 }
 
+QCString MemberDef::memberTypeName() const
+{
+  switch (mtype)
+  {
+    case Define:      return "define";
+    case Function:    return "function";
+    case Variable:    return "variable";
+    case Typedef:     return "typedef";
+    case Enumeration: return "enumeration"; 
+    case EnumValue:   return "enumvalue";
+    case Prototype:   return "prototype";   
+    case Signal:      return "signal";
+    case Slot:        return "slot";
+    case Friend:      return "friend";
+    case DCOP:        return "dcop";
+    case Property:    return "property";
+    case Event:       return "event";
+    default:          return "unknown";
+  }
+}
+
 void MemberDef::warnIfUndocumented()
 {
   if (memberGroup) return;
@@ -1875,19 +2028,20 @@ void MemberDef::warnIfUndocumented()
     t="group", d=gd;
   else
     t="file", d=fd;
+  static bool extractAll = Config_getBool("EXTRACT_ALL");
 
   //printf("warnIfUndoc: d->isLinkable()=%d isLinkable()=%d "
   //       "isDocumentedFriendClass()=%d name()=%s prot=%d\n",
   //       d->isLinkable(),isLinkable(),isDocumentedFriendClass(),
   //       name().data(),prot);
-  if (!isLinkable() && 
-      !isDocumentedFriendClass() && 
+  if ((!hasUserDocumentation() && !extractAll) &&
+      !isFriendClass() && 
       name().find('@')==-1 && d->name().find('@')==-1 &&
       (prot!=Private || Config_getBool("EXTRACT_PRIVATE"))
      )
   {
-    warn_undoc(m_defFileName,m_defLine,"Warning: Member %s%s of %s %s is not documented.",
-         name().data(),argsString()?argsString():"",t,d->name().data());
+    warn_undoc(m_defFileName,m_defLine,"Warning: Member %s%s (%s) of %s %s is not documented.",
+         name().data(),argsString()?argsString():"",memberTypeName().data(),t,d->name().data());
   }
 }
 
@@ -1898,13 +2052,21 @@ void MemberDef::warnIfUndocumented()
 //  *enumDeclList+=ed;
 //}
 
+bool MemberDef::isFriendClass() const
+{
+  return (isFriend() && 
+         (type=="friend class" || type=="friend struct" || 
+          type=="friend union"));
+}
+
 bool MemberDef::isDocumentedFriendClass() const
 {
   ClassDef *fcd=0;
-  return (isFriend() && 
-         (type=="friend class" || type=="friend struct" || 
-          type=="friend union") &&
-         (fcd=getClass(name())) && fcd->isLinkable()); 
+  QCString baseName=name();
+  int i=baseName.find('<');
+  if (i!=-1) baseName=baseName.left(i);
+  return (isFriendClass() &&
+         (fcd=getClass(baseName)) && fcd->isLinkable()); 
 }
 
 bool MemberDef::hasDocumentation() const
@@ -1934,9 +2096,48 @@ QCString MemberDef::getScopeString() const
   return result;
 }
 
+#if 0
+static QCString escapeAnchor(const QCString &anchor)
+{
+  QCString result;
+  int l = anchor.length(),i;
+  for (i=0;i<l;i++)
+  {
+    char c = anchor.at(i);
+    if ((c>='a' && c<='z') || (c>='A' && c<='Z'))
+    {
+      result+=c;
+    }
+    else
+    {
+      static char hexStr[]="0123456789ABCDEF";
+      char escChar[]={ '_', 0, 0, 0 };
+      escChar[1]=hexStr[c>>4];
+      escChar[2]=hexStr[c&0xf];
+      result+=escChar;
+    }
+  }
+  return result;
+}
+#endif
+
 void MemberDef::setAnchor(const char *a)
 {
-  anc=a;
+  //anc=a;
+  a=a;
+  QCString memAnchor = name();
+  if (!args.isEmpty()) memAnchor+=args;
+
+  // include definition as well, to distinguish between two template
+  // specializations that only differ in the template parameters.
+  memAnchor.prepend(definition());
+  
+  // convert to md5 hash
+  uchar md5_sig[16];
+  QCString sigStr(33);
+  MD5Buffer((const unsigned char *)memAnchor.data(),memAnchor.length(),md5_sig);
+  MD5SigToString(md5_sig,sigStr.data(),33);
+  anc = sigStr;
 }
 
 void MemberDef::setGroupDef(GroupDef *gd,Grouping::GroupPri_t pri,
@@ -1998,10 +2199,16 @@ MemberDef *MemberDef::createTemplateInstanceMember(
     actualArgList->pureSpecifier     = defArgList->pureSpecifier;
   }
 
+  QCString methodName=name();
+  if (methodName.left(9)=="operator ") // conversion operator
+  {
+    methodName=substituteTemplateArgumentsInString(methodName,formalArgs,actualArgs);
+  }
+
   MemberDef *imd = new MemberDef(
                        getDefFileName(),getDefLine(),
                        substituteTemplateArgumentsInString(type,formalArgs,actualArgs), 
-                       name(), 
+                       methodName, 
                        substituteTemplateArgumentsInString(args,formalArgs,actualArgs), 
                        exception, prot,
                        virt, stat, related, mtype, 0, 0
@@ -2047,10 +2254,13 @@ void MemberDef::setInitializer(const char *initializer)
 
 void MemberDef::addListReference(Definition *)
 {
+  static bool optimizeOutputForC = Config_getBool("OPTIMIZE_OUTPUT_FOR_C");
+  static bool hideScopeNames     = Config_getBool("HIDE_SCOPE_NAMES");
+  static bool optimizeOutputJava = Config_getBool("OPTIMIZE_OUTPUT_JAVA");
   visited=TRUE;
   if (!isLinkableInProject()) return;
   QCString memLabel;
-  if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C")) 
+  if (optimizeOutputForC) 
   {
     memLabel=theTranslator->trGlobal(TRUE,TRUE);
   }
@@ -2059,25 +2269,37 @@ void MemberDef::addListReference(Definition *)
     memLabel=theTranslator->trMember(TRUE,TRUE);
   }
   QCString memName = name();
-  if (!Config_getBool("HIDE_SCOPE_NAMES"))
+  Definition *pd=getOuterScope();
+  QCString memArgs;
+  if (!isRelated() &&
+      (
+       (!hideScopeNames && // there is a scope
+        pd && pd!=Doxygen::globalScope)       // and we can show it
+       ||
+       (pd=getClassDef())                     // it's a class so we
+                                              // show the scope anyway
+      )
+     )
   {
-    Definition *pd=getOuterScope();
-    if (pd && pd!=Doxygen::globalScope)
+    if (isObjCMethod())
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
-      {
-        memName.prepend(pd->name()+".");
-      }
-      else
-      {
-        memName.prepend(pd->name()+"::");
-      }
+      memName = "[" + pd->name() + " " + name() + "]";
+    }
+    else if (optimizeOutputJava)
+    {
+      memName.prepend(pd->name()+".");
+      memArgs = argsString();
+    }
+    else
+    {
+      memName.prepend(pd->name()+"::");
+      memArgs = argsString();
     }
   }
   if (xrefListItems())
   {
     addRefItem(xrefListItems(),memLabel,
-        getOutputFileBase()+"#"+anchor(),memName,argsString());
+        getOutputFileBase()+"#"+anchor(),memName,memArgs);
   }
   else 
   {
@@ -2110,14 +2332,47 @@ Specifier MemberDef::virtualness() const
 bool MemberDef::isConstructor() const            
 { 
   if (classDef) 
-     return name()==classDef->localName();
+  {
+    if (m_isDMember) // for D
+    {
+      return name()=="this";
+    }
+    else if (fileDef && getLanguageFromFileName(fileDef->name())==SrcLangExt_PHP)
+    {                // for PHP
+      return name()=="__construct";
+    }
+    else // for other languages
+    {
+      QCString locName = classDef->localName();
+      int i=locName.find('<');
+      if (i==-1) // not a template class
+      {
+        return name()==locName;
+      }
+      else
+      {
+        return name()==locName.left(i);
+      }
+    }
+  }
   else
      return FALSE; 
 }
 
 bool MemberDef::isDestructor() const
 { 
-  return name().find('~')!=-1 && name().find("operator")==-1; 
+  if (m_isDMember) // for D
+  {
+    return name()=="~this";
+  }
+  else if (fileDef && getLanguageFromFileName(fileDef->name())==SrcLangExt_PHP)
+  {                // for PHP
+    return name()=="__destruct";
+  }
+  else // other languages
+  {
+    return name().find('~')!=-1 && name().find("operator")==-1; 
+  }
 }
 
 void MemberDef::writeEnumDeclaration(OutputList &typeDecl,
@@ -2265,6 +2520,12 @@ void MemberDef::enableCallGraph(bool e)
   if (e) Doxygen::parseSourcesNeeded = TRUE;
 }
 
+void MemberDef::enableCallerGraph(bool e) 
+{ 
+  m_hasCallerGraph=e; 
+  if (e) Doxygen::parseSourcesNeeded = TRUE;
+}
+
 bool MemberDef::protectionVisible() const
 {
   return prot==Public || 
@@ -2306,3 +2567,30 @@ QCString MemberDef::qualifiedName()
   }  
 }
 
+void MemberDef::setTagInfo(TagInfo *ti)
+{
+  if (ti)
+  {
+    anc=ti->anchor;
+    setReference(ti->tagName);
+    explicitOutputFileBase = stripExtension(ti->fileName);
+  }
+}
+
+QCString MemberDef::objCMethodName(bool localLink,bool showStatic) const
+{
+  QCString qm;
+  if (showStatic)
+  {
+    if (isStatic()) qm="+ "; else qm="- ";
+  }
+  qm+=name();
+  if (!localLink) // link to method of same class
+  {
+    qm+=" (";
+    qm+=classDef->name();
+    qm+=")";
+  }
+  return qm;
+}
+
