@@ -2,7 +2,7 @@
  *
  * $Id: namespacedef.h,v 1.18 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -69,7 +69,7 @@ class NamespaceDef : public Definition
       int i = name().findRev("::");
       if (i==-1) i=0; else i+=2;
       return !name().isEmpty() && name().at(i)!='@' &&
-              hasDocumentation() && !isReference();
+              hasDocumentation() && !isReference() && !isHidden();
     }
     bool isLinkable() const
     {
