@@ -3,7 +3,7 @@
  *
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  * Authors: Dimitri van Heesch, Miguel Lobo.
  *
  * Permission to use, copy, modify, and distribute this software and its
@@ -532,6 +532,12 @@ void PerlModDocVisitor::visit(DocSymbol *sy)
   case DocSymbol::Hash:    c = '#'; break;
   case DocSymbol::Percent: c = '%'; break;
   case DocSymbol::Quot:    c = '"'; break;
+  case DocSymbol::Lsquo:   s = "\\\'"; break;
+  case DocSymbol::Rsquo:   s = "\\\'"; break;
+  case DocSymbol::Ldquo:   c = '"'; break;
+  case DocSymbol::Rdquo:   c = '"'; break;
+  case DocSymbol::Ndash:   c = '-'; break;
+  case DocSymbol::Mdash:   s = "--"; break;
   case DocSymbol::Nbsp:    c = ''; break;
   case DocSymbol::Uml:     accent = "umlaut"; break;
   case DocSymbol::Acute:   accent = "acute"; break;
@@ -1165,10 +1171,21 @@ void PerlModDocVisitor::visitPre(DocParamList *pl)
   leaveText();
   m_output.openHash()
     .openList("parameters");
-  QStrListIterator li(pl->parameters());
-  const char *s;
-  for (li.toFirst();(s=li.current());++li)
+  //QStrListIterator li(pl->parameters());
+  //const char *s;
+  QListIterator<DocNode> li(pl->parameters());
+  DocNode *param;
+  for (li.toFirst();(param=li.current());++li)
   {
+    QCString s;
+    if (param->kind()==DocNode::Kind_Word)
+    {
+      s = ((DocWord*)param)->word(); 
+    }
+    else if (param->kind()==DocNode::Kind_LinkedWord)
+    {
+      s = ((DocLinkedWord*)param)->word(); 
+    }
     m_output.openHash()
       .addFieldQuotedString("name", s)
       .closeHash();
@@ -2214,11 +2231,67 @@ bool PerlModGenerator::generateDoxyStructurePM()
     "\t\t  [ \"hash\", \"ClassDetailed\",\n"
     "\t\t    {\n"
     "\t\t      doc => [ \"doc\", \"ClassDetailedDoc\" ],\n"
-    " \t\t    },\n"
+    "\t\t    },\n"
     "\t\t  ],\n"
     "\t      },\n"
     "\t    ],\n"
     "\t  ],\n"
+    "\tgroups =>\n"
+    "\t  [ \"list\", \"Groups\",\n"
+    "\t    [ \"hash\", \"Group\",\n"
+    "\t      {\n"
+    "\t\tname => [ \"string\", \"GroupName\" ],\n"
+    "\t\ttitle => [ \"string\", \"GroupTitle\" ],\n"
+    "\t\tfiles =>\n"
+    "\t\t  [ \"list\", \"Files\",\n"
+    "\t\t    [ \"hash\", \"File\",\n"
+    "\t\t      {\n"
+    "\t\t        name => [ \"string\", \"Filename\" ]\n"
+    "\t\t      }\n"
+    "\t\t    ],\n"
+    "\t\t  ],\n"
+    "\t\tclasses  =>\n"
+    "\t\t  [ \"list\", \"Classes\",\n"
+    "\t\t    [ \"hash\", \"Class\",\n"
+    "\t\t      {\n" 
+    "\t\t        name => [ \"string\", \"Classname\" ]\n"
+    "\t\t      }\n"
+    "\t\t    ],\n"
+    "\t\t  ],\n"
+    "\t\tnamespaces =>\n"
+    "\t\t  [ \"list\", \"Namespaces\",\n"
+    "\t\t    [ \"hash\", \"Namespace\",\n"
+    "\t\t      {\n" 
+    "\t\t        name => [ \"string\", \"NamespaceName\" ]\n"
+    "\t\t      }\n"
+    "\t\t    ],\n"
+    "\t\t  ],\n"
+    "\t\tpages =>\n"
+    "\t\t  [ \"list\", \"Pages\",\n"
+    "\t\t    [ \"hash\", \"Page\","
+    "\t\t      {\n"
+    "\t\t        title => [ \"string\", \"PageName\" ]\n"
+    "\t\t      }\n"
+    "\t\t    ],\n"
+    "\t\t  ],\n"
+    "\t\tgroups =>\n"
+    "\t\t  [ \"list\", \"Groups\",\n"
+    "\t\t    [ \"hash\", \"Group\",\n"
+    "\t\t      {\n"
+    "\t\t        title => [ \"string\", \"GroupName\" ]\n"
+    "\t\t      }\n"
+    "\t\t    ],\n"
+    "\t\t  ],\n"
+    "\t\tfunctions => memberlist(\"GroupFunction\"),\n"
+    "\t\tdetailed =>\n"
+    "\t\t  [ \"hash\", \"GroupDetailed\",\n"
+    "\t\t    {\n"
+    "\t\t      doc => [ \"doc\", \"GroupDetailedDoc\" ],\n"
+    "\t\t    },\n"
+    "\t\t  ],\n"
+    "\t      }\n"
+    "\t    ],\n"
+    "\t  ],\n"
     "      },\n"
     "    ];\n"
     "\n"
