@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -68,6 +68,12 @@ class PrintDocVisitor : public DocVisitor
 	case DocSymbol::Copy:    printf("&copy;"); break;
 	case DocSymbol::Apos:    printf("'"); break;
 	case DocSymbol::Quot:    printf("\""); break;
+        case DocSymbol::Lsquo:   printf("&lsquo;"); break;
+        case DocSymbol::Rsquo:   printf("&rsquo;"); break;
+        case DocSymbol::Ldquo:   printf("&ldquo;"); break;
+        case DocSymbol::Rdquo:   printf("&rdquo;"); break;
+        case DocSymbol::Ndash:   printf("&ndash;"); break;
+        case DocSymbol::Mdash:   printf("&mdash;"); break;
 	case DocSymbol::Uml:     printf("&%cuml;",s->letter()); break;
 	case DocSymbol::Acute:   printf("&%cacute;",s->letter()); break;
 	case DocSymbol::Grave:   printf("&%cgrave;",s->letter()); break;
@@ -547,12 +553,23 @@ class PrintDocVisitor : public DocVisitor
     void visitPre(DocParamList *pl)
     {
       indent_pre();
-      QStrListIterator sli(pl->parameters());
-      const char *s;
+      //QStrListIterator sli(pl->parameters());
+      QListIterator<DocNode> sli(pl->parameters());
+      //const char *s;
+      DocNode *param;
       printf("<parameters>");
-      for (sli.toFirst();(s=sli.current());++sli)
+      for (sli.toFirst();(param=sli.current());++sli)
       {
-        printf("<param>%s</param>",s);
+        printf("<param>");
+        if (param->kind()==DocNode::Kind_Word)
+        {
+          visit((DocWord*)param); 
+        }
+        else if (param->kind()==DocNode::Kind_LinkedWord)
+        {
+          visit((DocLinkedWord*)param); 
+        }
+        printf("</param>");
       }
       printf("\n");
     }
