@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -114,6 +114,12 @@ void RTFDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Reg:     m_t << "(R)"; break;
     case DocSymbol::Apos:    m_t << "'"; break;
     case DocSymbol::Quot:    m_t << "\""; break;
+    case DocSymbol::Lsquo:   m_t << "`"; break;
+    case DocSymbol::Rsquo:   m_t << "'"; break;
+    case DocSymbol::Ldquo:   m_t << "\""; break;
+    case DocSymbol::Rdquo:   m_t << "\""; break;
+    case DocSymbol::Ndash:   m_t << "-"; break;
+    case DocSymbol::Mdash:   m_t << "--"; break;
     case DocSymbol::Uml:     switch(s->letter())
                              {
                                case 'A' : m_t << '\304'; break;
@@ -404,7 +410,7 @@ void RTFDocVisitor::visit(DocInclude *inc)
          m_t << rtf_Style_Reset << getStyle("CodeExample");
          QFileInfo cfi( inc->file() );
          FileDef fd( cfi.dirPath(), cfi.fileName() );
-         Doxygen::parserManager->getParser(m_langExt)
+         Doxygen::parserManager->getParser(inc->extension())
                                ->parseCode(m_ci,inc->context(),
                                            inc->text().latin1(),
                                            inc->isExample(),
@@ -417,7 +423,7 @@ void RTFDocVisitor::visit(DocInclude *inc)
       m_t << "{" << endl;
       m_t << "\\par" << endl;
       m_t << rtf_Style_Reset << getStyle("CodeExample");
-      Doxygen::parserManager->getParser(m_langExt)
+      Doxygen::parserManager->getParser(inc->extension())
                             ->parseCode(m_ci,inc->context(),
                                         inc->text().latin1(),inc->isExample(),
                                         inc->exampleFile());
