@@ -2,7 +2,7 @@
  *
  * $Id: rtfgen.h,v 1.13 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2005 by Parker Waechter & Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Parker Waechter & Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -101,6 +101,8 @@ class RTFGenerator : public OutputGenerator
     void endMemberHeader() { endGroupHeader(); }
     void startMemberSubtitle(); 
     void endMemberSubtitle(); 
+    void startMemberDocList() {}
+    void endMemberDocList() {}
     void startMemberList();
     void endMemberList();
     void startAnonTypeScope(int) {}
