@@ -2,7 +2,7 @@
  *
  * $Id: searchindex.cpp,v 1.7 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -64,11 +64,13 @@ SearchIndex::SearchIndex() : m_words(328829), m_index(numIndexEntries), m_urlInd
   int i;
   m_words.setAutoDelete(TRUE);
   m_urls.setAutoDelete(TRUE);
+  m_index.setAutoDelete(TRUE);
   for (i=0;i<numIndexEntries;i++) m_index.insert(i,new QList<IndexWord>);
 }
 
 void SearchIndex::setCurrentDoc(const char *name,const char *baseName,const char *anchor)
 {
+  if (name==0 || baseName==0) return;
   //printf("SearchIndex::setCurrentDoc(%s,%s,%s)\n",name,baseName,anchor);
   QCString url=baseName+Config_getString("HTML_FILE_EXTENSION");
   if (anchor) url+=(QCString)"#"+anchor;  
@@ -103,8 +105,8 @@ void SearchIndex::addWord(const char *word,bool hiPriority)
   //printf("SearchIndex::addWord(%s,%d)\n",word,hiPriority);
   //QString wStr=QString(word).lower();
   QString wStr(word);
-  wStr=wStr.lower();
   if (wStr.isEmpty()) return;
+  wStr=wStr.lower();
   IndexWord *w = m_words[wStr];
   if (w==0)
   {
@@ -279,7 +281,7 @@ void SearchIndex::write(const char *fileName)
     }
   }
 
-  delete urlOffsets;
-  delete wordStatOffsets;
+  delete[] urlOffsets;
+  delete[] wordStatOffsets;
 }
 
