@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -65,6 +65,9 @@
 // 2004/09/14 - The new methods "since 1.3.9" implemented. 
 // 2005/02/11 - The "never used" methods removed.
 // 2005/03/08 - Update for "new since 1.4.1" (trOverloadText()) 
+// 2006/05/10 - Update for "new since 1.4.6" -- trCallerGraph(), 
+//              modified trCallGraph() to make the meaning unambiguous
+//              and clear in the Czech language.
 
 // Todo
 // ----
@@ -84,7 +87,7 @@
 // Windows version. The version which does not call the function is
 // probably slightly faster.
 
-class TranslatorCzech : public Translator
+class TranslatorCzech : public TranslatorAdapter_1_4_6
 {
   private:
     /*! The decode() inline assumes the source written in the 
@@ -1488,7 +1491,7 @@ class TranslatorCzech : public Translator
     /*! Put in front of the call graph for a function. */
     virtual QCString trCallGraph()
     {
-      return decode("Graf voln pro tuto funkci:");
+      return decode("Tato funkce vol...");
     }
    
 //////////////////////////////////////////////////////////////////////////
@@ -1620,6 +1623,17 @@ class TranslatorCzech : public Translator
               "kter m usnadnit pouvn. Od ve uveden metody se li "
               "pouze jinak zadvanmi argumenty.");
     }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.6
+//////////////////////////////////////////////////////////////////////////
+
+    virtual QCString trCallerGraph()
+    {
+      return decode("Tuto funkci volaj...");
+    }
+
+
 };
 
 #endif // TRANSLATOR_CZ_H
