@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -42,6 +42,10 @@
 */
 class TranslatorEnglish : public Translator
 {
+  protected:
+    friend class TranslatorAdapterBase;
+    virtual ~TranslatorEnglish() {}
+
   public:
 
     // --- Language control methods -------------------
@@ -471,7 +475,7 @@ class TranslatorEnglish : public Translator
      *  list of (global) variables
      */
     virtual QCString trEnumerationValues()
-    { return "Enumeration values"; }
+    { return "Enumerator"; }
     
     /*! This is used in the documentation of a file before the list of
      *  documentation blocks for defines
@@ -497,12 +501,6 @@ class TranslatorEnglish : public Translator
     virtual QCString trEnumerationTypeDocumentation()
     { return "Enumeration Type Documentation"; }
 
-    /*! This is used in the documentation of a file/namespace before the list 
-     *  of documentation blocks for enumeration values
-     */
-    virtual QCString trEnumerationValueDocumentation()
-    { return "Enumeration Value Documentation"; }
-
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for functions
      */
@@ -1573,7 +1571,7 @@ class TranslatorEnglish : public Translator
     { return "Directory Documentation"; }
 
     /*! This is used as the title of the directory index and also in the
-     *  Quick links of a HTML page, to link to the directory hierarchy.
+     *  Quick links of an HTML page, to link to the directory hierarchy.
      */
     virtual QCString trDirectories()
     { return "Directories"; }
@@ -1602,6 +1600,37 @@ class TranslatorEnglish : public Translator
       return result; 
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+       return "This is an overloaded member function, "
+              "provided for convenience. It differs from the above "
+              "function only in what argument(s) it accepts.";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.6
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used to introduce a caller (or called-by) graph */
+    virtual QCString trCallerGraph()
+    {
+      return "Here is the caller graph for this function:";
+    }
+
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for enumeration values
+     */
+    virtual QCString trEnumerationValueDocumentation()
+    { return "Enumerator Documentation"; }
+
+
 };
 
 #endif
