@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -58,11 +58,18 @@
 //
 // 2004/09/15
 // - Added strings for 1.3.9
+//
+// 2005/02/28
+// - Removed obsolete (unused) methods
+//
+// 2005/03/21
+// - Added strings for 1.4.1
+//
 
 #ifndef TRANSLATOR_HR_H
 #define TRANSLATOR_HR_H
 
-class TranslatorCroatian : public Translator
+class TranslatorCroatian : public TranslatorAdapter_1_4_6
 {
   private:
         /*! to avoid macro redefinition from translator_cz.h */
@@ -104,10 +111,8 @@ class TranslatorCroatian : public Translator
     { return decode("Dokumentacija typedef lanova"); }
     QCString trMemberEnumerationDocumentation()
     { return decode("Dokumentacija enumeracijskih lanova"); }
-    QCString trEnumerationValueDocumentation()
-    { return "Dokumentacija enumeracijskih vrijednosti"; }
     QCString trMemberFunctionDocumentation()
-        { return "Dokumentacija funkcija"; }
+    { return "Dokumentacija funkcija"; }
     QCString trMemberDataDocumentation()
     { return "Documentacija varijabli"; }
     QCString trMore()
@@ -149,8 +154,6 @@ class TranslatorCroatian : public Translator
 	}
     QCString trFileList()
     { return "Popis datoteka"; }
-    QCString trHeaderFiles()
-    { return "Header datoteke"; }
     QCString trCompoundMembers()
 	{
 		if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
@@ -217,16 +220,12 @@ class TranslatorCroatian : public Translator
 		  result+="datoteke u kojima se nalaze:";
       return decode(result);
     }
-    QCString trHeaderFilesDescription()
-    { return decode("Popis header datoteka koje ine API :"); }
     QCString trExamplesDescription()
     { return "Popis primjera :"; }
     QCString trRelatedPagesDescription()
     { return "Popis povezanih stranica:"; }
     QCString trModulesDescription()
     { return "Popis svih modula:"; }
-    QCString trNoDescriptionAvailable()
-    { return "Opis nije dostupan"; }
 
     QCString trDocumentation()
     { return "Dokumentacija"; }
@@ -314,14 +313,8 @@ class TranslatorCroatian : public Translator
     }
     QCString trForInternalUseOnly()
     { return decode("Iskljuivo za internu uporabu."); }
-    QCString trReimplementedForInternalReasons()
-        { return decode("Reimplementirano zbog internih razloga; "
-                                        "Nema utjecaja na API."); 
-    }
     QCString trWarning()
     { return "Upozorenje"; }
-    QCString trBugsAndLimitations()
-    { return decode("Greke i ogranienja"); }
     QCString trVersion()
     { return "Verzija"; }
     QCString trDate()
@@ -563,10 +556,6 @@ class TranslatorCroatian : public Translator
 // new since 0.49-991106
 //////////////////////////////////////////////////////////////////////////
 
-    QCString trSources()
-    {
-      return "Izvorne datoteke";
-    }
     QCString trDefinedAtLineInSourceFile()
     {
       return "Definirano u liniji @0 datoteke @1.";
@@ -852,11 +841,6 @@ class TranslatorCroatian : public Translator
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-      return decode("Suelja (interfaces)");
-    }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
@@ -882,11 +866,6 @@ class TranslatorCroatian : public Translator
     {
       return "Paketi";
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return "Dokumentacija paketa";
-    }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -996,17 +975,6 @@ class TranslatorCroatian : public Translator
       return decode(result); 
     }
    
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool singular)
-    { 
-      QCString result((first_capital ? "Polj" : "polj"));
-      result+= (singular ? "e" : "a");
-      return result; 
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names 
      *  of the category.
@@ -1272,6 +1240,20 @@ class TranslatorCroatian : public Translator
       if (!singular) result+="i"; 
       return result; 
     }
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+       return decode("Ovo je preoptereena funkcija (overload). "
+              "Razlikuje se od navedene metode "
+              "samo po vrsti argumenata koje prihvata.");
+    }
+
 };
 
 #endif
