@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -23,7 +23,7 @@
 
   \author Hendy Irawan <ceefour@gauldong.net>
  */
-class TranslatorIndonesian : public Translator
+class TranslatorIndonesian : public TranslatorAdapter_1_4_6
 {
   public:
 
