@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -19,6 +19,8 @@
  *
  * Revision history
  *
+ *  2006/05: translated new items used since version 1.4.6
+ *           corrected typo in trPackageMembers method
  *  2005/03: translated new items used since version 1.4.1
  *           removed unused methods listed in Petr Prikryl February 28 translator report
  *  2004/09: translated new items used since version 1.3.9
@@ -74,7 +76,7 @@
 #ifndef TRANSLATOR_IT_H
 #define TRANSLATOR_IT_H
 
-class TranslatorItalian : public Translator
+class TranslatorItalian : public TranslatorAdapter_1_4_6
 {
   public:
 
@@ -1362,7 +1364,7 @@ class TranslatorItalian : public Translator
      */
     virtual QCString trPackageMembers()
     {
-      return "Funczioni con visibilit di package";
+      return "Funzioni con visibilit di package";
     }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
@@ -1524,6 +1526,15 @@ class TranslatorItalian : public Translator
               "unicamente per gli argomenti passati.";
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.6
+//////////////////////////////////////////////////////////////////////////
+
+    virtual QCString trCallerGraph()
+    {
+      return "Questo  il grafo dei chiamanti di questa funzione:";
+    }
+
 };
 
 #endif
