@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -80,7 +80,7 @@
 //
  
 
-class TranslatorKorean : public Translator
+class TranslatorKorean : public TranslatorAdapter_1_4_6
 {
  private:
   	
