@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -49,10 +49,10 @@
 #ifndef TRANSLATOR_RU_H
 #define TRANSLATOR_RU_H
 
-class TranslatorRussian : public Translator
+class TranslatorRussian : public TranslatorAdapter_1_4_6
 {
   private:
-    /*! The Decode() inline assumes the source written in the 
+    /*! The decode() inline assumes the source written in the 
         Koi8-R encoding (maintainer dependent). 
      */
     inline QCString decode(const QCString & sInput)
@@ -216,10 +216,6 @@ class TranslatorRussian : public Translator
     virtual QCString trFileList()
     { return decode(""); }
 
-    /*! This is put above each page as a link to the list of all verbatim headers */
-    virtual QCString trHeaderFiles()
-    { return decode(" "); }
-
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     {
@@ -330,10 +326,6 @@ class TranslatorRussian : public Translator
       return decode( result );
     }
 
-    /*! This is an introduction to the page with the list of all header files. */
-    virtual QCString trHeaderFilesDescription()
-    { return decode("   ."); }
-
     /*! This is an introduction to the page with the list of all examples */
     virtual QCString trExamplesDescription()
     { return decode("  ."); }
@@ -346,12 +338,6 @@ class TranslatorRussian : public Translator
     virtual QCString trModulesDescription()
     { return decode("  ."); }
 
-    /*! This sentences is used in the annotated class/file lists if no brief
-     * description is given. 
-     */
-    virtual QCString trNoDescriptionAvailable()
-    { return decode(" "); }
-
     // index titles (the project name is prepended for these) 
 
 
@@ -501,12 +487,6 @@ class TranslatorRussian : public Translator
     virtual QCString trEnumerationTypeDocumentation()
     { return decode(""); }
 
-    /*! This is used in the documentation of a file/namespace before the list 
-     *  of documentation blocks for enumeration values
-     */
-    virtual QCString trEnumerationValueDocumentation()
-    { return decode(" "); }
-
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for functions
      */
@@ -566,20 +546,10 @@ class TranslatorRussian : public Translator
     virtual QCString trForInternalUseOnly()
     { return decode("   "); }
 
-    /*! this text is generated when the \\reimp command is used. */
-    virtual QCString trReimplementedForInternalReasons()
-    /*??*/
-    { return decode("   "); 
-    }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return decode(""); }
 
-    /*! this text is generated when the \\bug command is used. */
-    virtual QCString trBugsAndLimitations()
-    { return decode("  "); }
-
     /*! this text is generated when the \\version command is used. */
     virtual QCString trVersion()
     { return decode(""); }
@@ -881,10 +851,6 @@ class TranslatorRussian : public Translator
 // new since 0.49-991106
 //////////////////////////////////////////////////////////////////////////
 
-    virtual QCString trSources()
-    {
-      return decode(" .");
-    }
     virtual QCString trDefinedAtLineInSourceFile()
     {
       return decode(".    @1  @0");
@@ -1192,11 +1158,6 @@ class TranslatorRussian : public Translator
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-      return decode("");
-    }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
@@ -1229,11 +1190,6 @@ class TranslatorRussian : public Translator
     {
       return decode("");
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return decode("");
-    }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -1348,17 +1304,6 @@ class TranslatorRussian : public Translator
       return decode(result); 
     }
    
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool singular)
-    { 
-      QCString result((first_capital ? "" : ""));
-      result+=(singular ? "" : "");
-      return decode(result); 
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names 
      *  of the category.
@@ -1616,6 +1561,20 @@ class TranslatorRussian : public Translator
       if (singular) result+=""; else result+="";
       return decode( result ); 
     }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+       return decode( "      "
+              "  .     "
+              "  ." );
+    }
 };
 
 #endif
