@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -69,7 +69,7 @@ Problem!
 #ifndef TRANSLATOR_SE_H
 #define TRANSLATOR_SE_H
 
-class TranslatorSwedish : public Translator
+class TranslatorSwedish : public TranslatorAdapter_1_4_6
 {
   public:
 
@@ -187,9 +187,6 @@ class TranslatorSwedish : public Translator
     virtual QCString trFileList()
     { return "Fillista"; }
 
-    virtual QCString trHeaderFiles()
-    { return "Headerfiler"; }
-
     virtual QCString trCompoundMembers()
     {
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
@@ -314,9 +311,6 @@ class TranslatorSwedish : public Translator
       return result;
     }
 
-    virtual QCString trHeaderFilesDescription()
-    { return "Hr fljer headerfilerna som API:n bestr av:"; }
-
     virtual QCString trExamplesDescription()
     { return "Hr fljer en lista med alla exempel:"; }
 
@@ -326,9 +320,6 @@ class TranslatorSwedish : public Translator
     virtual QCString trModulesDescription()
     { return "Hr fljer en lista ver alla moduler:"; }
 
-    virtual QCString trNoDescriptionAvailable()
-    { return "Beskrivning saknas"; }
-
     virtual QCString trDocumentation()
     { return "Dokumentation"; }
 
@@ -411,9 +402,6 @@ class TranslatorSwedish : public Translator
     virtual QCString trEnumerationTypeDocumentation()
     { return "Dokumentation ver egenupprknande typer"; }
 
-    virtual QCString trEnumerationValueDocumentation()
-    { return "Dokumentation ver egenupprknande typers vrden"; }
-
     virtual QCString trFunctionDocumentation()
     { return "Dokumentation ver funktioner"; }
 
@@ -456,15 +444,9 @@ class TranslatorSwedish : public Translator
     virtual QCString trForInternalUseOnly()
     { return "Endast fr internt bruk."; }
 
-    virtual QCString trReimplementedForInternalReasons()
-    { return "Omskriven av intern anledning; API:n pverkas inte.";}
-
     virtual QCString trWarning()
     { return "Varning"; }
 
-    virtual QCString trBugsAndLimitations()
-    { return "Fel och begrnsningar"; }
-
     virtual QCString trVersion()
     { return "Version"; }
 
@@ -704,10 +686,6 @@ class TranslatorSwedish : public Translator
 // new since 0.49-991003
 //////////////////////////////////////////////////////////////////////////
 
-    virtual QCString trSources()
-    {
-      return "Kllor";
-    }
     virtual QCString trDefinedAtLineInSourceFile()
     {
       return "Definition p rad @0 i filen @1.";
@@ -1027,11 +1005,6 @@ class TranslatorSwedish : public Translator
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-      return "Grnssnitt";
-    }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
@@ -1065,11 +1038,6 @@ class TranslatorSwedish : public Translator
     {
       return "Paket";
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return "Paketdokumentation";
-    }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -1189,16 +1157,6 @@ class TranslatorSwedish : public Translator
       return result; 
     }
 
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool /*singular*/)
-    { 
-      QCString result((first_capital ? "Flt" : "flt"));
-      return result; 
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names 
      *  of the category.
@@ -1458,6 +1416,20 @@ class TranslatorSwedish : public Translator
       return result; 
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+      return "Det hr r en verlagrad medlemsfunktion "
+             "tillhandahllen fr bekvmlighet. Den enda som "
+             "skiljer sig frn ovanstende funktion r vilka "
+             "argument den tar emot.";
+    }
 
 	
 };
